interface StringObject {
    [key: string]: string;
}
interface ConstructorParamsObject {
    hostUrl: string;
    token?: string;
    headers?: StringObject;
}
declare class Api {
    static readonly USER_AGENT: string;
    private axios_client;
    private accessToken;
    private initializationHeaders;
    constructor(options: ConstructorParamsObject);
    get(url: string, options?: any): any;
    head(url: string, options?: any): any;
    post(url: string, data: any, options?: any): any;
    put(url: string, data: any, options?: any): any;
    patch(url: string, data?: any, options?: any): any;
    getTenantName(): any;
    getRealmName(): any;
    private handleSuccess;
    private handleFailure;
    private preRequestHeaderConfig;
}

declare const addressUrl = "/v2/addresses";
interface AddressObject {
    object: string;
    id: string;
    profile: string;
    line1: string;
    line2: string | null;
    line3: string | null;
    city: string | null;
    state: string | null;
    postal_code: string;
    country: string;
    created_at: string;
    nature: string | null;
}
interface AddressCreateRequest {
    profile: string;
    line1: string;
    line2?: string;
    line3?: string;
    city?: string;
    state?: string;
    postal_code: string;
    country: string;
}
interface AddressUpdateRequest {
    id: string;
    line2?: string;
    line3?: string;
    city?: string;
    state?: string;
}
interface AddressFetchAllRequest {
    profile: string;
}

declare const address_types_d_addressUrl: typeof addressUrl;
type address_types_d_AddressObject = AddressObject;
type address_types_d_AddressCreateRequest = AddressCreateRequest;
type address_types_d_AddressUpdateRequest = AddressUpdateRequest;
type address_types_d_AddressFetchAllRequest = AddressFetchAllRequest;
declare namespace address_types_d {
  export {
    address_types_d_addressUrl as addressUrl,
    address_types_d_AddressObject as AddressObject,
    address_types_d_AddressCreateRequest as AddressCreateRequest,
    address_types_d_AddressUpdateRequest as AddressUpdateRequest,
    address_types_d_AddressFetchAllRequest as AddressFetchAllRequest,
  };
}

interface ListResponse<T> {
    object: "list";
    data: T[];
}

declare class AddressService {
    private api;
    constructor(api: Api);
    /**
     * Fetch an Address
     * @param id string
     * @returns AddressObject
     **/
    fetch(id: string): Promise<AddressObject>;
    /**
     * Create an Address
     * @param data AddressCreateRequest object
     * @returns AddressObject
     **/
    create(data: AddressCreateRequest): Promise<AddressObject>;
    /**
     * Update the Address
     * @param data AddressUpdateRequest
     * @returns AddressObject
     */
    update(data: AddressUpdateRequest): Promise<AddressObject>;
    /**
     * Fetch all Addresses
     * @returns AddressObjects list
     **/
    fetchAll(params: AddressFetchAllRequest): Promise<ListResponse<AddressObject>>;
}

declare const FP_DASHBOARD_API_LOGS_URL = "/apilog";
interface ApiLogParams {
    srv_name?: string;
    duration?: string;
    fp_object_id?: string;
    size?: number;
    status_codes?: number;
    methods?: string;
    api_name?: string;
    request_id?: string;
    start_time?: string | number;
    end_time?: string | number;
}
interface ApiLogResponseObject {
    id: string;
    object: string;
    request_id: string;
    fp_object_id: string;
    method: string;
    path: string;
    api_id: string;
    api_name: string;
    referrer_api: string;
    resource_name: string;
    resource_group: string;
    url: string;
    request_headers: Record<string, string>;
    response_headers: Record<string, string>;
    request_body: any;
    response_body: any;
    request_size: number;
    response_size: number;
    query_params: Record<string, string>;
    status_code: number;
    timestamp: number;
    host_ip: string;
    srv_name: string;
}

declare const api_logs_types_d_FP_DASHBOARD_API_LOGS_URL: typeof FP_DASHBOARD_API_LOGS_URL;
type api_logs_types_d_ApiLogParams = ApiLogParams;
type api_logs_types_d_ApiLogResponseObject = ApiLogResponseObject;
declare namespace api_logs_types_d {
  export {
    api_logs_types_d_FP_DASHBOARD_API_LOGS_URL as FP_DASHBOARD_API_LOGS_URL,
    api_logs_types_d_ApiLogParams as ApiLogParams,
    api_logs_types_d_ApiLogResponseObject as ApiLogResponseObject,
  };
}

declare class ApiLogsService {
    private api;
    constructor(api: Api);
    /**
     * Fetch a API Response
     * @param id API log id
     * @returns ApiLogObject
     * @deprecated use sparsely
     */
    fetch(id: string): Promise<ApiLogResponseObject>;
    /**
     * Get API logs
     * @param params API logs query params
     * @returns API logs response object
     **/
    fetchAll(params?: ApiLogParams): Promise<ListResponse<ApiLogResponseObject>>;
}

declare const authUrl = "/v2/auth";
interface TokenObject {
    access_token: string;
    expires_in: number;
    refresh_token?: string;
    refresh_expires_in?: number;
    token_type: string;
    ["not-before-policy"]: number;
    scope: string;
}
interface GetTokenResponse {
    access_token: string;
    expires_in: number;
    refresh_expires_in: number;
    token_type: string;
    ["not-before-policy"]: number;
    scope: string;
}
interface OAuthTokenOptions {
    client_id: string;
    client_secret: string;
    grant_type: string;
    tenant: string;
}

declare const auth_types_d_authUrl: typeof authUrl;
type auth_types_d_TokenObject = TokenObject;
type auth_types_d_GetTokenResponse = GetTokenResponse;
type auth_types_d_OAuthTokenOptions = OAuthTokenOptions;
declare namespace auth_types_d {
  export {
    auth_types_d_authUrl as authUrl,
    auth_types_d_TokenObject as TokenObject,
    auth_types_d_GetTokenResponse as GetTokenResponse,
    auth_types_d_OAuthTokenOptions as OAuthTokenOptions,
  };
}

declare class AuthService {
    private api;
    constructor(api: Api);
    /**
     *
     * @param data
     * @returns TokenObject
     */
    fetchTenantToken(data: OAuthTokenOptions): Promise<TokenObject>;
}

declare const bankAccountUrl = "/v2/bank_accounts";
interface BankAccountObject {
    object: string;
    id: string;
    old_id: string;
    profile: string;
    primary_account_holder_name: string;
    account_number: string;
    type: string;
    ifsc_code: string;
    branch_name: string;
    bank_name: string;
    branch_address: string;
    branch_contact_number: string;
    branch_city: string;
    branch_district: string;
    branch_state: string;
    cancelled_cheque: string | null;
    created_at: string;
}
interface BankAccountCreateRequest {
    profile: string;
    account_number: string;
    primary_account_holder_name: string;
    type: string;
    ifsc_code: string;
    cancelled_cheque?: string;
}
interface BankAccountUpdateRequest {
    id: string;
    cancelled_cheque: string;
}
interface BankAccountFetchAllRequest {
    profile: string;
}

declare const bank_account_types_d_bankAccountUrl: typeof bankAccountUrl;
type bank_account_types_d_BankAccountObject = BankAccountObject;
type bank_account_types_d_BankAccountCreateRequest = BankAccountCreateRequest;
type bank_account_types_d_BankAccountUpdateRequest = BankAccountUpdateRequest;
type bank_account_types_d_BankAccountFetchAllRequest = BankAccountFetchAllRequest;
declare namespace bank_account_types_d {
  export {
    bank_account_types_d_bankAccountUrl as bankAccountUrl,
    bank_account_types_d_BankAccountObject as BankAccountObject,
    bank_account_types_d_BankAccountCreateRequest as BankAccountCreateRequest,
    bank_account_types_d_BankAccountUpdateRequest as BankAccountUpdateRequest,
    bank_account_types_d_BankAccountFetchAllRequest as BankAccountFetchAllRequest,
  };
}

declare class BankAccountService {
    private api;
    constructor(api: Api);
    /**
     * Create a bank account
     * @param data CreateBankAccountRequest object
     * @returns BankAccountObject
     **/
    create(data: BankAccountCreateRequest): Promise<BankAccountObject>;
    /**
     * Update the BankAccount
     * @param data BankAccountUpdateRequest
     * @returns BankAccountObject
     */
    update(data: BankAccountUpdateRequest): Promise<BankAccountObject>;
    /**
     * Fetch an Bank Account
     * @param id number
     * @returns BankAccountObject
     **/
    fetch(id: string | number): Promise<BankAccountObject>;
    /**
     * Fetch all Bank Account
     * @returns BankAccountObjects list
     **/
    fetchAll(params: BankAccountFetchAllRequest): Promise<ListResponse<BankAccountObject>>;
}

declare const dematAccountsURL = "/v2/demat_accounts";
interface DematAccountObject {
    object: string;
    id: string;
    profile: string;
    dp_id: string;
    client_id: string;
    created_at: string;
}
interface DematAccountsFetchAllRequestParams {
    profile: string;
}
interface DematAccountsCreateRequest {
    profile: string;
    dp_id: string;
    client_id: string;
}

declare const demat_accounts_types_d_dematAccountsURL: typeof dematAccountsURL;
type demat_accounts_types_d_DematAccountObject = DematAccountObject;
type demat_accounts_types_d_DematAccountsFetchAllRequestParams = DematAccountsFetchAllRequestParams;
type demat_accounts_types_d_DematAccountsCreateRequest = DematAccountsCreateRequest;
declare namespace demat_accounts_types_d {
  export {
    demat_accounts_types_d_dematAccountsURL as dematAccountsURL,
    demat_accounts_types_d_DematAccountObject as DematAccountObject,
    demat_accounts_types_d_DematAccountsFetchAllRequestParams as DematAccountsFetchAllRequestParams,
    demat_accounts_types_d_DematAccountsCreateRequest as DematAccountsCreateRequest,
  };
}

declare class DematAccountsService {
    private api;
    constructor(api: Api);
    /**
     *
     * @param {DematAccountsCreateRequest} dematAccountData Demat Account creation data
     * @returns {Promise<DematAccountObject>} Created Demat Account Object
     */
    create(dematAccountData: DematAccountsCreateRequest): Promise<DematAccountObject>;
    /**
     *
     * @param {string} dematAccountId Demat Account object id
     * @returns {Promise<DematAccountObject>} Demat Account Object
     */
    fetch(dematAccountId: string): Promise<DematAccountObject>;
    /**
     *
     * @param {DematAccountsFetchAllRequestParams} params Fetch by profile request parameters
     * @returns {Promise<CommonUtils.ListResponse<DematAccountObject>>} Demat Account List
     */
    fetchAll(params: DematAccountsFetchAllRequestParams): Promise<ListResponse<DematAccountObject>>;
}

declare const emailAddressUrl = "/v2/email_addresses";
interface EmailAddressObject {
    object: string;
    id: string;
    profile: string;
    email: string;
    belongs_to: string | null;
    created_at: string;
}
interface EmailAddressCreateRequest {
    profile: string;
    email: string;
    belongs_to?: string;
}
interface EmailAddressUpdateRequest {
    id: string;
    belongs_to: string;
}
interface EmailAddressFetchAllRequest {
    profile: string;
}

declare const email_address_types_d_emailAddressUrl: typeof emailAddressUrl;
type email_address_types_d_EmailAddressObject = EmailAddressObject;
type email_address_types_d_EmailAddressCreateRequest = EmailAddressCreateRequest;
type email_address_types_d_EmailAddressUpdateRequest = EmailAddressUpdateRequest;
type email_address_types_d_EmailAddressFetchAllRequest = EmailAddressFetchAllRequest;
declare namespace email_address_types_d {
  export {
    email_address_types_d_emailAddressUrl as emailAddressUrl,
    email_address_types_d_EmailAddressObject as EmailAddressObject,
    email_address_types_d_EmailAddressCreateRequest as EmailAddressCreateRequest,
    email_address_types_d_EmailAddressUpdateRequest as EmailAddressUpdateRequest,
    email_address_types_d_EmailAddressFetchAllRequest as EmailAddressFetchAllRequest,
  };
}

declare class EmailAddressService {
    private api;
    constructor(api: Api);
    /**
     * Fetch an EmailAddress
     * @param id string
     * @returns EmailAddressObject
     **/
    fetch(id: string): Promise<EmailAddressObject>;
    /**
     * Create an EmailAddress
     * @param data AddressCreateRequest object
     * @returns EmailAddressObject
     **/
    create(data: EmailAddressCreateRequest): Promise<EmailAddressObject>;
    /**
     * Update the EmailAddress
     * @param data AddressUpdateRequest
     * @returns EmailAddressObject
     */
    update(data: EmailAddressUpdateRequest): Promise<EmailAddressObject>;
    /**
     * Fetch all EmailAddresses
     * @returns EmailAddressObjects list
     **/
    fetchAll(params: EmailAddressFetchAllRequest): Promise<ListResponse<EmailAddressObject>>;
}

declare const esignUrl = "/v2/esigns";
interface EsignCreateRequest {
    kyc_request: string;
    postback_url: string;
}
interface EsignObject {
    object: string;
    id: string;
    type: number;
    kyc_request: string;
    redirect_url: string;
    status: string;
    postback_url: number;
    created_at: string;
}

declare const esign_types_d_esignUrl: typeof esignUrl;
type esign_types_d_EsignCreateRequest = EsignCreateRequest;
type esign_types_d_EsignObject = EsignObject;
declare namespace esign_types_d {
  export {
    esign_types_d_esignUrl as esignUrl,
    esign_types_d_EsignCreateRequest as EsignCreateRequest,
    esign_types_d_EsignObject as EsignObject,
  };
}

declare class EsignService {
    private api;
    constructor(api: Api);
    /**
     * Fetch a Esign
     * @param id of the esign
     * @returns EsignObject
     */
    fetch(id: string): Promise<EsignObject>;
    /**
     * Create an Esign
     * @param data EsignCreateRequest object
     * @returns EsignObject
     */
    create(data: EsignCreateRequest): Promise<EsignObject>;
}

declare const eventsURL = "/v2/events";
interface EventData {
    object: Record<string, any>;
    previous_attributes?: Record<string, any> | null;
}
interface EventObject {
    object: string;
    id: string;
    type: string;
    data: EventData;
    time: string;
}
interface EventsFetchAllRequestParams {
    type?: string;
    fp_object_id?: string;
    from_date?: string;
    to_date?: string;
}

declare const events_types_d_eventsURL: typeof eventsURL;
type events_types_d_EventData = EventData;
type events_types_d_EventObject = EventObject;
type events_types_d_EventsFetchAllRequestParams = EventsFetchAllRequestParams;
declare namespace events_types_d {
  export {
    events_types_d_eventsURL as eventsURL,
    events_types_d_EventData as EventData,
    events_types_d_EventObject as EventObject,
    events_types_d_EventsFetchAllRequestParams as EventsFetchAllRequestParams,
  };
}

declare class EventsService {
    private api;
    constructor(api: Api);
    /**
     *
     * @param {string} eventId Event object id
     * @returns {Promise<EventObject>}
     */
    fetch(eventId: string): Promise<EventObject>;
    /**
     *
     * @param {EventsFetchAllRequestParams} params EventsFetchAllRequestParams
     * @returns {Promise<CommonUtils.ListResponse<EventObject>>} EventObject List
     */
    fetchAll(params?: EventsFetchAllRequestParams): Promise<ListResponse<EventObject>>;
    /**
     *
     * @returns {Promise<CommonUtils.ListResponse<string>>} Event types list
     */
    fetchAllEventTypes(): Promise<ListResponse<string>>;
}

declare const fileUrl = "/files";
interface FileResponse {
    object: string;
    id: string;
    created_at: string;
    filename: string;
    content_type: string;
    purpose: string | null;
    byte_size: number;
    url: string;
}

declare const file_types_d_fileUrl: typeof fileUrl;
type file_types_d_FileResponse = FileResponse;
declare namespace file_types_d {
  export {
    file_types_d_fileUrl as fileUrl,
    file_types_d_FileResponse as FileResponse,
  };
}

declare class FileService {
    private api;
    constructor(api: Api);
    /**
     * Fetch a File
     * @param file id returned from upload file api.
     * @returns FileResponse
     */
    fetch(id: string): Promise<FileResponse>;
    /**
     * This API used to fetch all files orders with a limit of 100.
     * @returns List entity
     */
    fetchAll(): Promise<FileResponse[]>;
    /**
     * Create an file
     * @param data FileCreateRequest object
     * @returns FileResponse
     */
    create(data: FormData, customHeaders?: {}): Promise<FileResponse>;
}

declare const fileOperationUrl = "/file_operations";
interface FileOperationCreateRequest {
    file: string;
    type: string;
}
interface FileOperationObject {
    object: string;
    id: string;
    file: string;
    file_name: string;
    type: string;
    status: string;
    processed: number;
    failed: number;
    succeeded: number;
    created_at: string;
    updated_at: string;
}
interface FileOperationsFetchAllRequestParams {
    page?: number;
    size?: number;
}
interface FileOperationsFetchAllResponse {
    last: boolean;
    total_pages: number;
    total_elements: number;
    size: number;
    number: number;
    first: boolean;
    number_of_elements: number;
    data: FileOperationObject[];
}

declare const file_operation_types_d_fileOperationUrl: typeof fileOperationUrl;
type file_operation_types_d_FileOperationCreateRequest = FileOperationCreateRequest;
type file_operation_types_d_FileOperationObject = FileOperationObject;
type file_operation_types_d_FileOperationsFetchAllRequestParams = FileOperationsFetchAllRequestParams;
type file_operation_types_d_FileOperationsFetchAllResponse = FileOperationsFetchAllResponse;
declare namespace file_operation_types_d {
  export {
    file_operation_types_d_fileOperationUrl as fileOperationUrl,
    file_operation_types_d_FileOperationCreateRequest as FileOperationCreateRequest,
    file_operation_types_d_FileOperationObject as FileOperationObject,
    file_operation_types_d_FileOperationsFetchAllRequestParams as FileOperationsFetchAllRequestParams,
    file_operation_types_d_FileOperationsFetchAllResponse as FileOperationsFetchAllResponse,
  };
}

declare class FileOperationService {
    private api;
    constructor(api: Api);
    /**
     * Fetch a file_operation
     * @param id file_operation.
     * @returns FileOperationObject
     */
    fetch(id: string): Promise<FileOperationObject>;
    /**
     * Create an file_operation
     * @param data FileOperationCreateRequest object
     * @returns FileOperationObject
     */
    create(data: FileOperationCreateRequest): Promise<FileOperationObject>;
    fetchAll(params: FileOperationsFetchAllRequestParams): Promise<FileOperationsFetchAllResponse>;
}

declare const investorProfilesUrl = "/v2/investor_profiles";
declare type InvestorType = "individual";
declare type TaxStatus = "resident_individual" | "nri";
declare type Gender = "male" | "female" | "transgender";
declare type Occupation = "business" | "professional" | "retired" | "house_wife" | "student" | "public_sector_service" | "private_sector_service" | "government_service" | "others" | "agriculture" | "doctor" | "forex_dealer" | "service";
declare type SourceOfWealth = "salary" | "business" | "gift" | "ancestral_property" | "rental_income" | "prize_money" | "royalty" | "others";
declare type IncomeSlab = "upto_1lakh" | "above_1lakh_upto_5lakh" | "above_5lakh_upto_10lakh" | "above_10lakh_upto_25lakh" | "above_25lakh_upto_1cr" | "above_1cr";
declare type PepDetails = "pep_exposed" | "pep_related" | "not_applicable";
declare type TaxidTypeIN = "passport" | "election_id" | "pan" | "id_card" | "driving_license" | "aadhaar_letter" | "nrega_job_card" | "others" | "not_categorized" | "tin";
declare type TaxidTypeOther = "passport" | "id_card" | "driving_license" | "others" | "not_categorized" | "tin";
interface TaxResidency {
    country: string;
    taxid_type: TaxidTypeIN | TaxidTypeOther;
    taxid_number: string;
}
interface InvestorProfileObject {
    object: string;
    id: string;
    type: InvestorType;
    tax_status: TaxStatus;
    name: string;
    date_of_birth: string;
    gender: Gender;
    occupation: Occupation;
    pan: string;
    guardian_name?: string | null;
    guardian_date_of_birth?: string | null;
    guardian_pan?: string | null;
    signature?: string | null;
    country_of_birth: string;
    place_of_birth?: string | null;
    first_tax_residency?: TaxResidency | null;
    second_tax_residency?: TaxResidency | null;
    third_tax_residency?: TaxResidency | null;
    fourth_tax_residency?: TaxResidency | null;
    source_of_wealth?: SourceOfWealth | null;
    income_slab?: IncomeSlab | null;
    pep_details?: PepDetails | null;
    employer?: string | null;
    ip_address?: string | null;
    created_at: string;
}
interface InvestorProfileCreateRequest {
    type: string;
    tax_status?: string;
    name?: string;
    date_of_birth?: string;
    gender?: string;
    occupation?: string;
    pan?: string;
    guardian_name?: string;
    guardian_date_of_birth?: string;
    guardian_pan?: string;
    signature?: string;
    country_of_birth?: string;
    place_of_birth?: string;
    first_tax_residency?: TaxResidency;
    second_tax_residency?: TaxResidency;
    third_tax_residency?: TaxResidency;
    fourth_tax_residency?: TaxResidency;
    source_of_wealth?: string;
    income_slab?: string;
    pep_details?: string;
    ip_address?: string;
}
interface InvestorProfileUpdateRequest {
    id: string;
    tax_status?: string;
    name?: string;
    date_of_birth?: string;
    gender?: string;
    occupation?: string;
    pan?: string;
    guardian_name?: string;
    guardian_date_of_birth?: string;
    guardian_pan?: string;
    signature?: string;
    country_of_birth?: string;
    place_of_birth?: string;
    first_tax_residency?: TaxResidency;
    second_tax_residency?: TaxResidency;
    third_tax_residency?: TaxResidency;
    fourth_tax_residency?: TaxResidency;
    source_of_wealth?: string;
    income_slab?: string;
    pep_details?: string;
    ip_address?: string;
}
interface InvestorProfileFetchAllRequest {
    pan?: string;
    type?: string;
}

declare const investor_profile_types_d_investorProfilesUrl: typeof investorProfilesUrl;
type investor_profile_types_d_InvestorProfileObject = InvestorProfileObject;
type investor_profile_types_d_InvestorProfileCreateRequest = InvestorProfileCreateRequest;
type investor_profile_types_d_InvestorProfileUpdateRequest = InvestorProfileUpdateRequest;
type investor_profile_types_d_InvestorProfileFetchAllRequest = InvestorProfileFetchAllRequest;
declare namespace investor_profile_types_d {
  export {
    investor_profile_types_d_investorProfilesUrl as investorProfilesUrl,
    investor_profile_types_d_InvestorProfileObject as InvestorProfileObject,
    investor_profile_types_d_InvestorProfileCreateRequest as InvestorProfileCreateRequest,
    investor_profile_types_d_InvestorProfileUpdateRequest as InvestorProfileUpdateRequest,
    investor_profile_types_d_InvestorProfileFetchAllRequest as InvestorProfileFetchAllRequest,
  };
}

declare class InvestorProfileService {
    private api;
    constructor(api: Api);
    /**
     * Fetch an InvestorProfile
     * @param id string
     * @returns InvestorProfilesObject
     **/
    fetch(id: string): Promise<InvestorProfileObject>;
    /**
     * Create an InvestorProfile
     * @param data InvestorCreateRequest object
     * @returns InvestorProfilesObject
     **/
    create(data: InvestorProfileCreateRequest): Promise<InvestorProfileObject>;
    /**
     * Update the InvestorProfile
     * @param data InvestorPatchRequest
     * @returns InvestorProfilesObject
     */
    update(data: InvestorProfileUpdateRequest): Promise<InvestorProfileObject>;
    /**
     * Fetch all InvestorProfiles
     * @returns InvestorProfileObject list
     **/
    fetchAll(params: InvestorProfileFetchAllRequest): Promise<ListResponse<InvestorProfileObject>>;
}

declare const omsReportUrl = "/api/oms/reports";
declare const transactionReportsUrl$1 = "/v2/transactions/reports";
interface InvestorReportHoldingsFetchRequest {
    investment_account_id?: number;
    folios?: string;
    as_on?: string;
}
interface InvestorReportHoldingsFetchAllRequest extends InvestorReportHoldingsFetchRequest {
    investment_account_id?: number;
}
interface Scheme {
    isin: string;
    name: string;
    type: string;
    holdings: {
        as_on: string;
        units: number;
        redeemable_units: number;
    };
    market_value: {
        as_on: string;
        amount: number;
        redeemable_amount: number;
    };
    invested_value: {
        as_on: string;
        amount: number;
    };
    payout: {
        as_on: string;
        amount: number;
    };
    nav: {
        as_on: string;
        value: number;
    };
}
interface Folio {
    folio_number: string;
    schemes: Scheme[];
}
interface InvestorReportHoldingsFetchResponse {
    id: number;
    folios: Folio[];
}
interface InvestorReportCapitalGainFetchRequest {
    mf_investment_account: string;
    folios?: string;
    scheme?: string;
    traded_on_from?: string;
    traded_on_to?: string;
}
interface InvestorReportCapitalGainFetchResponse {
    folio_number: string;
    isin: string;
    type: string;
    amount: number;
    units: number;
    traded_on: string;
    traded_at: number;
    source_days_held: number;
    source_units: number;
    source_purchased_on: string;
    source_purchased_at: number;
    source_actual_gain: number;
    source_taxable_gain: number;
    grand_fathering: boolean;
    grand_fathering_nav: number;
    indexed_capital_gain: number;
}
interface InvestorReportSchemewiseReturnsFetchRequest {
    mf_investment_account: string;
    traded_on_to?: string;
}
interface InvestorReportSchemewiseReturnsResponse {
    isin: string;
    scheme_name: string;
    plan_type: string;
    investment_option: number;
    as_on: number;
    nav: string;
    invested_amount: number;
    current_value: number;
    unrealized_gain: number;
    absolute_return: string;
    average_buying_value: number;
    units: number;
    xirr: number;
}
interface InvestorReportInvestmentAccountWiseReturnsFetchRequest {
    mf_investment_account: string;
    traded_on_to?: string;
}
interface InvestorReportInvestmentAccountWiseReturnsFetchResponse {
    mf_investment_account: string;
    invested_amount: number;
    current_value: number;
    unrealized_gain: number;
    absolute_return: number;
    xirr: number;
}

declare const investor_report_types_d_omsReportUrl: typeof omsReportUrl;
type investor_report_types_d_InvestorReportHoldingsFetchRequest = InvestorReportHoldingsFetchRequest;
type investor_report_types_d_InvestorReportHoldingsFetchAllRequest = InvestorReportHoldingsFetchAllRequest;
type investor_report_types_d_InvestorReportHoldingsFetchResponse = InvestorReportHoldingsFetchResponse;
type investor_report_types_d_InvestorReportCapitalGainFetchRequest = InvestorReportCapitalGainFetchRequest;
type investor_report_types_d_InvestorReportCapitalGainFetchResponse = InvestorReportCapitalGainFetchResponse;
type investor_report_types_d_InvestorReportSchemewiseReturnsFetchRequest = InvestorReportSchemewiseReturnsFetchRequest;
type investor_report_types_d_InvestorReportSchemewiseReturnsResponse = InvestorReportSchemewiseReturnsResponse;
type investor_report_types_d_InvestorReportInvestmentAccountWiseReturnsFetchRequest = InvestorReportInvestmentAccountWiseReturnsFetchRequest;
type investor_report_types_d_InvestorReportInvestmentAccountWiseReturnsFetchResponse = InvestorReportInvestmentAccountWiseReturnsFetchResponse;
declare namespace investor_report_types_d {
  export {
    investor_report_types_d_omsReportUrl as omsReportUrl,
    transactionReportsUrl$1 as transactionReportsUrl,
    investor_report_types_d_InvestorReportHoldingsFetchRequest as InvestorReportHoldingsFetchRequest,
    investor_report_types_d_InvestorReportHoldingsFetchAllRequest as InvestorReportHoldingsFetchAllRequest,
    investor_report_types_d_InvestorReportHoldingsFetchResponse as InvestorReportHoldingsFetchResponse,
    investor_report_types_d_InvestorReportCapitalGainFetchRequest as InvestorReportCapitalGainFetchRequest,
    investor_report_types_d_InvestorReportCapitalGainFetchResponse as InvestorReportCapitalGainFetchResponse,
    investor_report_types_d_InvestorReportSchemewiseReturnsFetchRequest as InvestorReportSchemewiseReturnsFetchRequest,
    investor_report_types_d_InvestorReportSchemewiseReturnsResponse as InvestorReportSchemewiseReturnsResponse,
    investor_report_types_d_InvestorReportInvestmentAccountWiseReturnsFetchRequest as InvestorReportInvestmentAccountWiseReturnsFetchRequest,
    investor_report_types_d_InvestorReportInvestmentAccountWiseReturnsFetchResponse as InvestorReportInvestmentAccountWiseReturnsFetchResponse,
  };
}

declare class InvestorReportService {
    private api;
    constructor(api: Api);
    /**
     * Fetch holdings report for an investment account or a set of folio numbers
     * @param InvestorReportHoldingsFetchRequest
     * @returns InvestorReportHoldingsFetchResponse
     */
    fetchHoldings(params: InvestorReportHoldingsFetchAllRequest): Promise<InvestorReportHoldingsFetchResponse>;
    /**
     * This API used to fetch Holdings report for an investment account.
     * @returns InvestorReportHoldingsFetchResponse
     */
    fetchHoldingsForIa(id: number, params?: InvestorReportHoldingsFetchRequest): Promise<InvestorReportHoldingsFetchResponse[]>;
    /**
     * Fetch capital gains report for an investment account
     * @param InvestorReportCapitalGainFetchRequest
     * @returns InvestorReportCapitalGainFetchResponse
     */
    fetchCapitalGains(params: InvestorReportCapitalGainFetchRequest): Promise<InvestorReportCapitalGainFetchResponse[]>;
    /**
     * Fetch scheme wise returns report for an investment account
     * @param InvestorReportSchemewiseReturnsFetchRequest
     * @returns InvestorReportSchemewiseReturnsResponse
     */
    fetchSchemewiseReturns(data: InvestorReportSchemewiseReturnsFetchRequest): Promise<InvestorReportSchemewiseReturnsResponse[]>;
    /**
     * Fetch Investment account returns report for an investment account
     * @param InvestorReportInvestmentAccountWiseReturnsFetchRequest
     * @returns InvestorReportInvestmentAccountWiseReturns
     */
    fetchInvestmentAccountWiseReturns(params: InvestorReportInvestmentAccountWiseReturnsFetchRequest): Promise<InvestorReportInvestmentAccountWiseReturnsFetchResponse>;
    c: any;
}

declare const investorsURL = "/api/onb/investors";
interface InvestorBankAccount {
    account_holder_name?: string;
    number?: string;
    primary_account?: boolean;
    type?: "SAVINGS" | "CURRENT" | "NRE" | "NRO";
    cancelled_cheque?: string;
    id?: string;
    branch?: {
        ifsc_code?: string | null;
        micr_code?: string | null;
        branch_name?: string | null;
        bank_name?: string | null;
        branch_address?: string | null;
        contact?: string | null;
        city?: string | null;
        district?: string | null;
        state?: string | null;
    };
    created_at?: string | null;
    updated_at?: string | null;
}
interface InvestorContactDetails {
    email: string;
    isd_code: number;
    mobile: string;
    office_telephone_no?: string;
    residence_telephone_no?: string;
}
interface InvestorFatcaDetails {
    country_of_birth_ansi_code: string;
    no_other_tax_residences: boolean;
    source_of_wealth: "SALARY" | "BUSINESS" | "GIFT" | "ANCESTRAL_PROPERTY" | "RENTAL_INCOME" | "PRIZE_MONEY" | "ROYALTY" | "OTHERS";
    gross_annual_income: number;
    first_trc_ansi_code?: string;
    first_trc_taxid_type?: string;
    first_trc_taxid_number?: string;
    second_trc_ansi_code?: string;
    second_trc_taxid_type?: string;
    second_trc_taxid_number?: string;
    third_trc_ansi_code?: string;
    third_trc_taxid_type?: string;
    third_trc_taxid_number?: string;
}
interface InvestorNominee {
    name: string;
    pan?: string;
    date_of_birth: string;
    relationship: string;
    allocation_percentage: number;
    guardian_name?: string;
    guardian_pan?: string;
    guardian_relationship?: string;
}
interface InvestorNomination {
    skip_nomination: boolean;
    nominee1?: InvestorNominee;
    nominee2?: InvestorNominee;
    nominee3?: InvestorNominee;
}
interface InvestorKycIdentityDetails {
    name: string;
    father_or_spouse_name?: string;
    mothers_name?: string;
    kyc_relation?: "FATHER" | "SPOUSE";
    country_of_citizenship_ansi_code: string;
    date_of_birth: string;
    gender: "MALE" | "FEMALE" | "OTHERS";
    marital_status: "MARRIED" | "SINGLE" | "OTHERS";
    residential_status: "RESIDENT_INDIVIDUAL" | "NON_RESIDENT_INDIVIDUAL";
    occupation: "AGRICULTURE" | "BUSINESS" | "DOCTOR" | "FOREX_DEALER" | "GOVERNMENT_SERVICE" | "HOUSE_WIFE" | "OTHERS" | "PRIVATE_SECTOR_SERVICE" | "PROFESSIONAL" | "PUBLIC_SECTOR_SERVICE" | "RETIRED" | "SERVICE" | "STUDENT";
    pan_number?: string;
    pan_exempt?: boolean;
    pep_exposed: boolean;
    pep_related: boolean;
    guardian_name?: string;
    guardian_relationship?: string;
    guardian_date_of_birth?: string;
    guardian_pan_number?: string;
    signature?: string;
}
interface InvestorAddress {
    line1?: string;
    line2?: string;
    line3?: string;
    city?: string;
    state?: string;
    pincode?: string;
    zipcode?: string;
    country_ansi_code?: string;
    type?: string;
}
interface InvestorCreateRequest {
    display_name?: string;
    perm_addr_is_corres_addr: boolean;
    bank_accounts: InvestorBankAccount[];
    contact_detail: InvestorContactDetails;
    fatca_detail: InvestorFatcaDetails;
    nomination: InvestorNomination;
    kyc_identity_detail: InvestorKycIdentityDetails;
    correspondence_address: InvestorAddress;
    permanent_address?: InvestorAddress;
    overseas_address?: InvestorAddress;
    ip_address?: string;
}
interface InvestorUpdateRequest extends InvestorCreateRequest {
    id: string;
}
interface InvestorObject {
    id: string;
    display_name: string;
    perm_addr_is_corres_addr: boolean;
    bank_accounts: InvestorBankAccount[];
    contact_detail: InvestorContactDetails;
    fatca_detail: InvestorFatcaDetails;
    nomination: InvestorNomination;
    kyc_identity_detail: InvestorKycIdentityDetails;
    correspondence_address: InvestorAddress;
    permanent_address?: InvestorAddress;
    overseas_address?: InvestorAddress;
    ip_address?: string;
    created_at: string;
}
interface InvestorFetchAllRequestParams {
    page?: number;
    size?: number;
}
interface InvestorSearchRequestParams {
    query?: string;
    bank_account_ids?: string;
    ids?: string;
    guardian_pan_numbers?: string;
    page?: number;
    size?: number;
}
interface InvestorListAllResponse {
    first: boolean;
    last: boolean;
    total_pages: number;
    number: number;
    size: number;
    total_elements: number;
    sort: unknown;
    investors: InvestorObject[];
}

declare const investors_types_d_investorsURL: typeof investorsURL;
type investors_types_d_InvestorBankAccount = InvestorBankAccount;
type investors_types_d_InvestorContactDetails = InvestorContactDetails;
type investors_types_d_InvestorFatcaDetails = InvestorFatcaDetails;
type investors_types_d_InvestorNominee = InvestorNominee;
type investors_types_d_InvestorNomination = InvestorNomination;
type investors_types_d_InvestorKycIdentityDetails = InvestorKycIdentityDetails;
type investors_types_d_InvestorAddress = InvestorAddress;
type investors_types_d_InvestorCreateRequest = InvestorCreateRequest;
type investors_types_d_InvestorUpdateRequest = InvestorUpdateRequest;
type investors_types_d_InvestorObject = InvestorObject;
type investors_types_d_InvestorFetchAllRequestParams = InvestorFetchAllRequestParams;
type investors_types_d_InvestorSearchRequestParams = InvestorSearchRequestParams;
type investors_types_d_InvestorListAllResponse = InvestorListAllResponse;
declare namespace investors_types_d {
  export {
    investors_types_d_investorsURL as investorsURL,
    investors_types_d_InvestorBankAccount as InvestorBankAccount,
    investors_types_d_InvestorContactDetails as InvestorContactDetails,
    investors_types_d_InvestorFatcaDetails as InvestorFatcaDetails,
    investors_types_d_InvestorNominee as InvestorNominee,
    investors_types_d_InvestorNomination as InvestorNomination,
    investors_types_d_InvestorKycIdentityDetails as InvestorKycIdentityDetails,
    investors_types_d_InvestorAddress as InvestorAddress,
    investors_types_d_InvestorCreateRequest as InvestorCreateRequest,
    investors_types_d_InvestorUpdateRequest as InvestorUpdateRequest,
    investors_types_d_InvestorObject as InvestorObject,
    investors_types_d_InvestorFetchAllRequestParams as InvestorFetchAllRequestParams,
    investors_types_d_InvestorSearchRequestParams as InvestorSearchRequestParams,
    investors_types_d_InvestorListAllResponse as InvestorListAllResponse,
  };
}

/**
 * @deprecated use v2 investor profiles
 */
declare class InvestorService {
    private api;
    constructor(api: Api);
    /**
     * Creates a new Investor.
     * @param {InvestorCreateRequest} investorData Investor creation data
     * @returns {Promise<InvestorObject>} Created Investor object
     * @deprecated use v2 investor profiles
     */
    create(investorData: InvestorCreateRequest): Promise<InvestorObject>;
    /**
     * Updates an existing Investor's details.
     * @param {string} investorId Investor ID
     * @param {InvestorUpdateRequest} investorData Investor update data
     * @returns {Promise<InvestorObject>} Updated Investor object
     * @deprecated use v2 investor profiles
     */
    update(investorId: string, investorData: InvestorUpdateRequest): Promise<InvestorObject>;
    /**
     * Fetches an Investor by ID.
     * @param {string} investorId Investor ID
     * @returns {Promise<InvestorObject>} Investor object
     * @deprecated use v2 investor profiles
     */
    fetch(investorId: string): Promise<InvestorObject>;
    /**
     * Fetches all Investors.
     * @param {InvestorFetchAllRequestParams} params Fetch all request parameters
     * @returns {Promise<InvestorListAllResponse>} List of Investors
     * @deprecated use v2 investor profiles
     */
    fetchAll(params: InvestorFetchAllRequestParams): Promise<InvestorListAllResponse>;
    /**
     * Searches for Investors based on certain filters.
     * @param {InvestorSearchRequestParams} params Search request parameters
     * @returns {Promise<InvestorListAllResponse>} List of Investors matching the search criteria
     * @deprecated use v2 investor profiles
     */
    search(params: InvestorSearchRequestParams): Promise<InvestorListAllResponse>;
}

declare const kycCheckUrl = "/api/kyc";
interface source {
    name: string;
    response_verbatim: string;
    fetched_at: string;
}
interface KycCheckResponse {
    id: string;
    source_ref_id: string;
    pan: string;
    entity_details: {};
    status: boolean;
    constraints: {
        type: string;
        amount: {
            value: number;
            currency: string;
        };
    };
    sources: source[];
    created_at: string;
    updated_at: string;
}
interface KycCheckCreateRequest {
    pan: string;
}

declare const kyc_check_types_d_kycCheckUrl: typeof kycCheckUrl;
type kyc_check_types_d_KycCheckResponse = KycCheckResponse;
type kyc_check_types_d_KycCheckCreateRequest = KycCheckCreateRequest;
declare namespace kyc_check_types_d {
  export {
    kyc_check_types_d_kycCheckUrl as kycCheckUrl,
    kyc_check_types_d_KycCheckResponse as KycCheckResponse,
    kyc_check_types_d_KycCheckCreateRequest as KycCheckCreateRequest,
  };
}

declare class KycCheckService {
    private api;
    constructor(api: Api);
    /**
     * Fetch a kyc check
     * @param identifier
     * @returns KycCheckResponse
     **/
    fetch(identifier: string): Promise<KycCheckResponse>;
    /**
     * Create a kyc check
     * @param KycCheckCreateRequest
     * @returns KycCheckResponse
     **/
    create(data: KycCheckCreateRequest): Promise<KycCheckResponse>;
    /**
     * Re-Fetch a kyc check
     * @param identifier
     * @returns KycCheckResponse
     **/
    refetch(identifier: string): Promise<KycCheckResponse>;
}

declare const kycRequestUrl = "/v2/kyc_requests";
interface MustPresent {
    name: string;
    pan: string;
    email: string;
    date_of_birth: string;
    mobile: Mobile;
}
interface Optional {
    aadhaar_number: string;
    father_name: string;
    spouse_name: string;
    mother_name: string;
    gender: string;
    country_of_birth: string;
    marital_status: string;
    residential_status: string;
    occupation_type: string;
    geolocation: Geolocation;
    bank_account: BankAccount$1;
    address: Address$1;
    identity_proof: string;
    ipv_video: string;
    signature: string;
    photo: string;
    otp: string;
    status: string;
    created_at: string;
    updated_at: string;
    esign_required_at: string;
    submitted_at: string;
    successful_at: string;
    rejected_at: string;
    expires_at: string;
    verification: Verification;
    requirements: {
        fields_needed: string[];
    };
}
interface KycRequestCreateRequest extends MustPresent, Partial<Optional> {
}
interface Address$1 {
    city: string;
    proof: string;
    line_1: string;
    line_2?: string;
    line_3?: string;
    country: string;
    pincode: string;
    proof_back: string;
    proof_type: string;
    proof_number: string;
    proof_issue_date: string;
    proof_expiry_date: string;
}
interface BankAccount$1 {
    account_holder_name: string;
    account_number: string;
    ifsc_code: string;
    proof: string;
}
interface Verification {
    status: string;
    details: {
        pan: string;
        signature: string;
        "address.proof": string;
    };
    details_verbose: {
        pan: {
            code: string;
            reason: string;
        };
        signature: {
            code: string;
            reason: string;
        };
        "address.proof": {
            code: string;
            reason: string;
        };
    };
}
interface Mobile {
    isd: string;
    number: string;
}
interface Geolocation {
    latitude: number;
    longitude: number;
}
interface KycRequestResponse extends MustPresent, Optional {
    object: string;
    id: string;
}
interface KycRequestPatchRequest extends Partial<MustPresent>, Partial<Optional> {
}
interface KycRequestFetchAllRequest {
    pan?: string;
    status?: string;
}
interface KycRequestSimulateRequest {
    status: string;
}

declare const kyc_request_types_d_kycRequestUrl: typeof kycRequestUrl;
type kyc_request_types_d_KycRequestCreateRequest = KycRequestCreateRequest;
type kyc_request_types_d_KycRequestResponse = KycRequestResponse;
type kyc_request_types_d_KycRequestPatchRequest = KycRequestPatchRequest;
type kyc_request_types_d_KycRequestFetchAllRequest = KycRequestFetchAllRequest;
type kyc_request_types_d_KycRequestSimulateRequest = KycRequestSimulateRequest;
declare namespace kyc_request_types_d {
  export {
    kyc_request_types_d_kycRequestUrl as kycRequestUrl,
    kyc_request_types_d_KycRequestCreateRequest as KycRequestCreateRequest,
    kyc_request_types_d_KycRequestResponse as KycRequestResponse,
    kyc_request_types_d_KycRequestPatchRequest as KycRequestPatchRequest,
    kyc_request_types_d_KycRequestFetchAllRequest as KycRequestFetchAllRequest,
    kyc_request_types_d_KycRequestSimulateRequest as KycRequestSimulateRequest,
  };
}

declare class KycRequestService {
    private api;
    constructor(api: Api);
    /**
     * Fetch a kyc request
     * @param id of the KYC Request
     * @returns KycRequestResponse
     */
    fetch(id: string): Promise<KycRequestResponse>;
    /**
     * This API used to fetch all kyc request with a limit of 100.
     * @params KycRequestFetchAllRequest
     * @returns List entity
     */
    fetchAll(params: KycRequestFetchAllRequest): Promise<ListResponse<KycRequestResponse>>;
    /**
     * Create an kyc request
     * @param data KycRequestCreateRequest object
     * @returns KycRequestResponse
     */
    create(data: KycRequestCreateRequest): Promise<KycRequestResponse>;
    /**
     * update kyc request
     * @param data KycRequestPatchRequest
     * @returns KycRequestResponse
     */
    update(id: string, data: KycRequestPatchRequest): Promise<KycRequestResponse>;
}

declare const mandateUrl = "/api/pg/mandates";
interface MandateCreateRequest {
    mandate_type: string;
    bank_account_id: number;
    mandate_limit: number;
    provider_name?: string;
    valid_from?: string;
    valid_to?: string;
}
interface MandateCreateResponse {
    id: string;
}
interface MandateAuthorizeRequest {
    mandate_id: number;
    payment_postback_url?: string;
}
interface MandateAuthorizeResponse {
    token_url: string;
    id: number;
}
interface MandateFetchResponse {
    id: string;
    bank_account_id: number;
    mandate_ref: string;
    mandate_token: string;
    valid_from: string;
    valid_to: string;
    provider_name: "RAZORPAY" | "BILLDESK";
    mandate_limit: number;
    mandate_type: string;
    mandate_status: string;
    umrn: string | null;
    created_at: string;
    received_at: string;
    submitted_at: string | null;
    cancelled_at: string | null;
    approved_at: string | null;
    rejected_at: string | null;
    rejected_reason: string | null;
    provider_id: string;
}
interface MandateFetchAllRequest {
    bank_account_id?: string;
    page?: number;
    size?: number;
}
interface MandateFetchAllResponse {
    last: boolean;
    total_pages: number;
    total_elements: number;
    size: number;
    number: number;
    first: boolean;
    number_of_elements: number;
    mandates: MandateFetchResponse[];
}

declare const mandate_types_d_mandateUrl: typeof mandateUrl;
type mandate_types_d_MandateCreateRequest = MandateCreateRequest;
type mandate_types_d_MandateCreateResponse = MandateCreateResponse;
type mandate_types_d_MandateAuthorizeRequest = MandateAuthorizeRequest;
type mandate_types_d_MandateAuthorizeResponse = MandateAuthorizeResponse;
type mandate_types_d_MandateFetchResponse = MandateFetchResponse;
type mandate_types_d_MandateFetchAllRequest = MandateFetchAllRequest;
type mandate_types_d_MandateFetchAllResponse = MandateFetchAllResponse;
declare namespace mandate_types_d {
  export {
    mandate_types_d_mandateUrl as mandateUrl,
    mandate_types_d_MandateCreateRequest as MandateCreateRequest,
    mandate_types_d_MandateCreateResponse as MandateCreateResponse,
    mandate_types_d_MandateAuthorizeRequest as MandateAuthorizeRequest,
    mandate_types_d_MandateAuthorizeResponse as MandateAuthorizeResponse,
    mandate_types_d_MandateFetchResponse as MandateFetchResponse,
    mandate_types_d_MandateFetchAllRequest as MandateFetchAllRequest,
    mandate_types_d_MandateFetchAllResponse as MandateFetchAllResponse,
  };
}

declare class MandateService {
    private api;
    constructor(api: Api);
    /**
     * Fetch a Mandate
     * @param id  of the Mandate.
     * @returns MandateFetchResponse
     */
    fetch(id: number): Promise<MandateFetchResponse>;
    /**
     * This API used to fetch all Mandates with a limit of 100.
     * @returns MandateFetchAllRequest
     */
    fetchAll(params: MandateFetchAllRequest): Promise<MandateFetchAllResponse>;
    /**
     * Create an Mandate
     * @param data MandateCreateRequest object
     * @returns MandateCreateResponse
     */
    create(data: MandateCreateRequest): Promise<MandateCreateResponse>;
    /**
     * Authorize the Mandate order
     * @param data MandateAuthorizeRequest
     * @returns MandateAuthorizeResponse
     */
    authorize(data: MandateAuthorizeRequest): Promise<MandateAuthorizeResponse>;
    /**
     * Cancel Mandate
     * @param id string
     * @returns MandateFetchResponse
     */
    cancel(id: number): Promise<MandateFetchResponse>;
}

declare const fundSchemeUrl = "/api/oms/fund_schemes/";
interface SchemeResponse {
    fund_scheme_id: number;
    isin: string;
    active: boolean;
    name: string;
    investment_option: string;
    min_initial_investment: number | null;
    min_additional_investment: number | null;
    initial_investment_multiples: number | null;
    max_initial_investment: number | null;
    max_additional_investment: number | null;
    additional_investment_multiples: number | null;
    min_withdrawal_amount: number | null;
    min_withdrawal_units: number | null;
    max_withdrawal_amount: number | null;
    max_withdrawal_units: number | null;
    withdrawal_multiples: number | null;
    sip_allowed: boolean;
    min_sip_amount: number | null;
    max_sip_amount: number | null;
    min_sip_installments: number | null;
    sip_multiples: number | null;
    sip_frequency_data: FrequencyData;
    swp_frequency_data: FrequencyData;
    stp_frequency_data: FrequencyData;
    switch_in_allowed: boolean;
    switch_in_min_amt: number | null;
    switch_multiples: number | null;
    fund_category: string;
    plan_type: string;
    amfi_code: string | null;
    sub_category: string | null;
    scheme_code: string;
    close_ended: boolean;
    lock_in: boolean;
    lock_in_period: number | null;
    long_term_period: number | null;
    purchase_allowed: boolean;
    redemption_allowed: boolean;
    insta_redemption_allowed: boolean;
    amc_id: number;
    rta_id: number;
    merged: boolean;
    merged_to_isin: string | null;
    name_changes: NameChanges;
    swp_allowed: boolean;
    min_swp_amount: number;
    max_swp_amount: number;
    min_swp_installments: number;
    swp_multiples: number;
    stp_out_allowed: boolean;
    stp_in_allowed: true;
    min_stp_in_amount: number | null;
    max_stp_in_amount: number | null;
    min_stp_out_installments: number | null;
    stp_in_amount_multiples: number | null;
    min_switch_in_amount: number | null;
    switch_in_amount_multiples: number | null;
    merger_date: string | null;
    switch_out_allowed: boolean;
    min_switch_out_amount: number | null;
    min_switch_out_units: number | null;
    switch_out_unit_multiples: number | null;
    switch_out_amount_multiples: number | null;
    delivery_mode: "DEMAT_PHYSICAL" | "DEMAT" | "PHYSICAL";
    sip_frequency_specific_data: FrequencySpecificObject;
    swp_frequency_specific_data: FrequencySpecificObject;
    stp_frequency_specific_data: FrequencySpecificObject;
    withdrawal_multiples_units: number | null;
}
interface FrequencySpecificObject {
    day_in_a_week?: FrequencySpecificData;
    four_times_a_month?: FrequencySpecificData;
    day_in_a_fortnight?: FrequencySpecificData;
    twice_a_month?: FrequencySpecificData;
    monthly?: FrequencySpecificData;
    quarterly?: FrequencySpecificData;
    "half-yearly"?: FrequencySpecificData;
    yearly?: FrequencySpecificData;
}
interface FrequencySpecificData {
    dates: number[];
    min_installment_amount: number;
    max_installment_amount: number;
    amount_multiples: number;
    min_installments: number;
}
interface FrequencyData {
    MONTHLY: string;
}
interface NameChanges {
    history: History[];
}
interface History {
    old_name: string;
    old_name_valid_upto: string;
}
declare const ifscCodesUrl = "/api/onb/ifsc_codes/";
interface IfscCodeResponse {
    ifsc_code: string;
    micr_code: string | null;
    branch_name: string;
    branch_address: string;
    bank_name: string;
    contact: string;
    city: string;
    district: string;
    state: string;
}
declare const pinCodeUrl = "/api/onb/pincodes/";
interface PinCodeLink {
    href: string;
    rel: string;
    method: string;
}
interface PincodeResponse {
    code: string;
    city: string;
    district: string;
    state_name: string;
    country_ansi_code: string;
    _links: PinCodeLink[];
}
declare const statesUrl = "/api/onb/states";
interface State {
    name: string;
    state_code: string;
    country_ansi_code: string;
}
interface StateResponse {
    states: State[];
}
declare const countryUrl = "/api/onb/countries";
interface Country {
    name: string;
    ansi_code: string;
}
interface CountryResponse {
    countries: Country[];
}
declare const amcUrl = "/api/oms/amcs/";
interface Amc {
    id: number;
    name: string;
    active: boolean;
    amc_code: string | null;
    amc_id: number;
}
interface AmcLink {
    self: {
        href: string;
    };
}
interface AmcResponse {
    _links: AmcLink;
    amcs: Amc[];
}
interface FundSchemesParams {
    page?: number;
    size?: number;
    amc_id?: string;
    investment_option?: string;
    plan_type?: string;
    delivery_mode?: string;
    fund_category?: string;
    name?: string;
}
interface SchemesListResponse {
    last: boolean;
    total_pages: number;
    total_elements: number;
    size: number;
    number: number;
    first: boolean;
    number_of_elements: number;
    fund_schemes: SchemeResponse[];
}

declare const master_data_types_d_fundSchemeUrl: typeof fundSchemeUrl;
type master_data_types_d_SchemeResponse = SchemeResponse;
type master_data_types_d_FrequencySpecificObject = FrequencySpecificObject;
declare const master_data_types_d_ifscCodesUrl: typeof ifscCodesUrl;
type master_data_types_d_IfscCodeResponse = IfscCodeResponse;
declare const master_data_types_d_pinCodeUrl: typeof pinCodeUrl;
type master_data_types_d_PincodeResponse = PincodeResponse;
declare const master_data_types_d_statesUrl: typeof statesUrl;
type master_data_types_d_StateResponse = StateResponse;
declare const master_data_types_d_countryUrl: typeof countryUrl;
type master_data_types_d_Country = Country;
type master_data_types_d_CountryResponse = CountryResponse;
declare const master_data_types_d_amcUrl: typeof amcUrl;
type master_data_types_d_Amc = Amc;
type master_data_types_d_AmcResponse = AmcResponse;
type master_data_types_d_FundSchemesParams = FundSchemesParams;
type master_data_types_d_SchemesListResponse = SchemesListResponse;
declare namespace master_data_types_d {
  export {
    master_data_types_d_fundSchemeUrl as fundSchemeUrl,
    master_data_types_d_SchemeResponse as SchemeResponse,
    master_data_types_d_FrequencySpecificObject as FrequencySpecificObject,
    master_data_types_d_ifscCodesUrl as ifscCodesUrl,
    master_data_types_d_IfscCodeResponse as IfscCodeResponse,
    master_data_types_d_pinCodeUrl as pinCodeUrl,
    master_data_types_d_PincodeResponse as PincodeResponse,
    master_data_types_d_statesUrl as statesUrl,
    master_data_types_d_StateResponse as StateResponse,
    master_data_types_d_countryUrl as countryUrl,
    master_data_types_d_Country as Country,
    master_data_types_d_CountryResponse as CountryResponse,
    master_data_types_d_amcUrl as amcUrl,
    master_data_types_d_Amc as Amc,
    master_data_types_d_AmcResponse as AmcResponse,
    master_data_types_d_FundSchemesParams as FundSchemesParams,
    master_data_types_d_SchemesListResponse as SchemesListResponse,
  };
}

declare class MasterDataService {
    private api;
    constructor(api: Api);
    /**
     * [Get] details of the given pincode
     * @param pincode
     * @returns PincodeResponse
     **/
    fetchPincode(pincode: string): Promise<PincodeResponse>;
    /**
     * [Get] all states of India which are updated in the system
     * @returns StateResponse
     **/
    fetchStates(): Promise<StateResponse>;
    /**
     * [Get] the list of countries updated in the system
     * @returns CountryResponse
     **/
    fetchCountries(): Promise<CountryResponse>;
    /**
     * [Get] all the AMCs.
     * @returns AmcResponse
     **/
    fetchAmcs(amcId?: number): Promise<AmcResponse>;
    /**
     * [GET] Single Fund Schemes Detail
     * @param identifier isin number
     * @returns SchemeResponse
     **/
    fetchScheme(identifier: string): Promise<SchemeResponse>;
    /**
     * [GET] Funds list
     * @param params FundSchemesParams
     * @returns SchemeResponse
     **/
    fetchSchemes(params?: FundSchemesParams): Promise<SchemesListResponse>;
    /**
     * Fetch bank details from ifsc code
     * @param ifsc_code  ifsc code
     * @returns IfscCodeResponse
     **/
    fetchIfscCodes(ifsc_code: string): Promise<IfscCodeResponse>;
}

declare const mfFolioUrl = "/v2/mf_folios";
interface MfFolioFetchAllRequest {
    mf_investment_account?: string;
    folio_number?: string;
    license_code?: string;
    primary_investor_name?: string;
    primary_investor_pan?: string;
}
interface MfFolioObject {
    object: string;
    amc: string;
    number: string;
    dp_id: string | null;
    client_id: string | null;
    primary_investor_pan: string;
    secondary_investor_pan: string | null;
    third_investor_pan: string | null;
    holding_pattern: string;
    primary_investor_name: string;
    secondary_investor_name: string | null;
    third_investor_name: string | null;
    primary_investor_dob: string;
    secondary_investor_dob: string | null;
    third_investor_dob: string | null;
    primary_investor_gender: string | null;
    secondary_investor_gender: string | null;
    third_investor_gender: string | null;
    primary_investor_tax_status: string;
    primary_investor_occupation: string;
    guardian_name: string | null;
    guardian_gender: string | null;
    guardian_pan: string | null;
    guardian_dob: string | null;
    guardian_relationship: string | null;
    nominee1: Nominee | null;
    nominee1_allocation_percentage: null;
    nominee2: Nominee | null;
    nominee2_allocation_percentage: null;
    nominee3: Nominee | null;
    nominee3_allocation_percentage: null;
    payout_details: Payout[];
    contact_details: ContactDetail[];
    email_addresses: string[];
    mobile_numbers: string[];
}
interface Payout {
    scheme: string | null;
    scheme_code: string;
    bank_account: BankAccount;
}
interface BankAccount {
    name: string;
    number: string;
    account_type: string;
    ifsc: string;
}
interface ContactDetail {
    address: Address;
    email: string | null;
    mobile: string | null;
    type: string;
}
interface Address {
    line1: string;
    line2: string;
    line3: string;
    city: string;
    state: string;
    postal_code: string;
    country_name: string | null;
    country_ansi_code: string | null;
}
interface Nominee {
    name: string | null;
    dob: string | null;
    relationship: string | null;
    guardian: string | null;
    guardian_relationship: string | null;
}

declare const mf_folio_types_d_mfFolioUrl: typeof mfFolioUrl;
type mf_folio_types_d_MfFolioFetchAllRequest = MfFolioFetchAllRequest;
type mf_folio_types_d_MfFolioObject = MfFolioObject;
declare namespace mf_folio_types_d {
  export {
    mf_folio_types_d_mfFolioUrl as mfFolioUrl,
    mf_folio_types_d_MfFolioFetchAllRequest as MfFolioFetchAllRequest,
    mf_folio_types_d_MfFolioObject as MfFolioObject,
  };
}

declare class MfFolioService {
    private api;
    constructor(api: Api);
    /**
     * Fetch an MF Folio
     * @param data of type FolioSearchI
     * @returns MfFolioObjects list
     **/
    fetchAll(params: MfFolioFetchAllRequest): Promise<ListResponse<MfFolioObject>>;
}

declare const mfInvestmentAccountUrl = "/v2/mf_investment_accounts";
interface MfInvestmentAccountObject {
    object: string;
    id: string;
    old_id: string;
    primary_investor: string | null;
    second_investor: string | null;
    third_investor: string | null;
    primary_investor_pan: string;
    second_investor_pan: string | null;
    third_investor_pan: string | null;
    primary_investor_old_id: number;
    second_investor_old_id: number | null;
    third_investor_old_id: number | null;
    holding_pattern: string;
    folio_defaults: FolioDefaults;
    created_at: string;
}
interface FolioDefaults {
    demat_account: string | null;
    communication_address: string | null;
    communication_email_address: string | null;
    communication_mobile_number: string | null;
    nominee1: string | null;
    nominee1_allocation_percentage: number | null;
    nominee2: string | null;
    nominee2_allocation_percentage: number | null;
    nominee3: string | null;
    nominee3_allocation_percentage: number | null;
    overseas_communication_address: string | null;
    payout_bank_account: string | null;
}
interface MfInvestmentAccountCreateRequest {
    primary_investor_old_id: string;
    holding_pattern?: string;
}
interface MfInvestmentAccountUpdateRequest {
    id: string;
    primary_investor_old_id: string;
}
interface MfInvestmentAccountFetchAllRequest {
    primary_investor_pan?: string;
    second_investor_pan?: string;
    third_investor_pan?: string;
    holding_pattern?: string;
    investor?: string;
}

declare const mf_investment_account_types_d_mfInvestmentAccountUrl: typeof mfInvestmentAccountUrl;
type mf_investment_account_types_d_MfInvestmentAccountObject = MfInvestmentAccountObject;
type mf_investment_account_types_d_FolioDefaults = FolioDefaults;
type mf_investment_account_types_d_MfInvestmentAccountCreateRequest = MfInvestmentAccountCreateRequest;
type mf_investment_account_types_d_MfInvestmentAccountUpdateRequest = MfInvestmentAccountUpdateRequest;
type mf_investment_account_types_d_MfInvestmentAccountFetchAllRequest = MfInvestmentAccountFetchAllRequest;
declare namespace mf_investment_account_types_d {
  export {
    mf_investment_account_types_d_mfInvestmentAccountUrl as mfInvestmentAccountUrl,
    mf_investment_account_types_d_MfInvestmentAccountObject as MfInvestmentAccountObject,
    mf_investment_account_types_d_FolioDefaults as FolioDefaults,
    mf_investment_account_types_d_MfInvestmentAccountCreateRequest as MfInvestmentAccountCreateRequest,
    mf_investment_account_types_d_MfInvestmentAccountUpdateRequest as MfInvestmentAccountUpdateRequest,
    mf_investment_account_types_d_MfInvestmentAccountFetchAllRequest as MfInvestmentAccountFetchAllRequest,
  };
}

declare class MfInvestmentAccountService {
    private api;
    constructor(api: Api);
    /**
     * Fetch a mf investment account
     * @param identifier V2 or V1 id of the investment account
     * @returns MfInvestmentAccountObject
     **/
    fetch(identifier: string): Promise<MfInvestmentAccountObject>;
    /**
     * FetchAll mf investment accounts
     * @params MfInvestmentAccountFetchAllRequest
     * @returns MfInvestmentAccountObjects list
     **/
    fetchAll(params: MfInvestmentAccountFetchAllRequest): Promise<ListResponse<MfInvestmentAccountObject>>;
    /**
     * Create a mf investment account
     * @param primary_investor_old_id( V1 investor id), holding_pattern
     * @returns MfInvestmentAccountObject
     **/
    create(data: MfInvestmentAccountCreateRequest): Promise<MfInvestmentAccountObject>;
    /**
     * Update a mf investment account
     * @param primary_investor_old_id( V1 investor id), V2 Id of the investment account
     * @returns MfInvestmentAccountObject
     **/
    update(data: MfInvestmentAccountUpdateRequest): Promise<MfInvestmentAccountObject>;
}

declare const mfPurchaseUrl = "/v2/mf_purchases";
interface MfPurchaseObject {
    object: string;
    id: string;
    old_id: number;
    mf_investment_account: string;
    folio_number: string;
    state: string;
    amount: number;
    allotted_units: number | null;
    purchased_amount: number | null;
    purchased_price: number | null;
    scheme: string;
    type: string;
    plan: string | null;
    scheduled_on: string;
    traded_on: string | null;
    created_at: string;
    confirmed_at: string | null;
    submitted_at: string | null;
    succeeded_at: string | null;
    failed_at: string | null;
    retried_at: string | null;
    reversed_at: string | null;
    gateway: string;
    source_ref_id: string;
    user_ip: string;
    server_ip: string;
    euin: string | null;
    distributor_id: string | null;
    failure_code: string | null;
    initiated_by: string;
    initiated_via: string;
    partner: string | null;
}
interface MfPurchaseCreateRequest {
    mf_investment_account: string;
    scheme: string;
    folio_number?: string;
    amount: number | string;
    user_ip?: string;
    server_ip?: string;
    source_ref_id?: string;
    euin?: string;
    partner?: string;
    scheduled_on?: string;
}
interface MfPurchasePatchRequest {
    id: string;
    state: string;
}
interface MfPurchaseFetchAllRequest {
    mf_investment_account?: string;
    plan_basket?: string;
    skip_instruction?: string;
    plan?: string;
    states?: string;
}

declare const mf_purchase_types_d_mfPurchaseUrl: typeof mfPurchaseUrl;
type mf_purchase_types_d_MfPurchaseObject = MfPurchaseObject;
type mf_purchase_types_d_MfPurchaseCreateRequest = MfPurchaseCreateRequest;
type mf_purchase_types_d_MfPurchasePatchRequest = MfPurchasePatchRequest;
type mf_purchase_types_d_MfPurchaseFetchAllRequest = MfPurchaseFetchAllRequest;
declare namespace mf_purchase_types_d {
  export {
    mf_purchase_types_d_mfPurchaseUrl as mfPurchaseUrl,
    mf_purchase_types_d_MfPurchaseObject as MfPurchaseObject,
    mf_purchase_types_d_MfPurchaseCreateRequest as MfPurchaseCreateRequest,
    mf_purchase_types_d_MfPurchasePatchRequest as MfPurchasePatchRequest,
    mf_purchase_types_d_MfPurchaseFetchAllRequest as MfPurchaseFetchAllRequest,
  };
}

declare class MfPurchaseService {
    private api;
    constructor(api: Api);
    /**
     * Fetch a MF Purchase
     * @param id V2 or V1 id of the purchase order.
     * @returns MfPurchaseObject
     */
    fetch(id: string): Promise<MfPurchaseObject>;
    /**
     * This API used to fetch all purchase orders with a limit of 100.
     * @returns MfPurchaseObjects list
     */
    fetchAll(params: MfPurchaseFetchAllRequest): Promise<ListResponse<MfPurchaseObject>>;
    /**
     * Create an mf_purchase
     * @param data MfPurchaseCreateRequest object
     * @returns MfPurchaseObject
     */
    create(data: MfPurchaseCreateRequest): Promise<MfPurchaseObject>;
    /**
     * Update the mf_purchase order
     * @param data MfPurchasePatchRequest
     * @returns MfPurchaseObject
     */
    update(data: MfPurchasePatchRequest): Promise<MfPurchaseObject>;
    /**
     * Retry mf purchase order in case of failure
     * @param id string
     * @returns MfPurchaseObject
     */
    retry(id: string): Promise<MfPurchaseObject>;
}

declare const mfPurchasePlanUrl = "/v2/mf_purchase_plans";
interface Consent$3 {
    email?: string;
    isd_code?: string;
    mobile?: string;
}
declare type Frequency = "daily" | "day_in_a_week" | "four_times_a_month" | "day_in_a_fortnight" | "twice_a_month" | "monthly" | "quarterly" | "half-yearly" | "yearly";
interface MfPurchasePlanObject {
    object: string;
    id: string;
    mf_investment_account: string;
    folio_number: string;
    scheme: string;
    amount: number | null;
    systematic: boolean;
    gateway: string;
    frequency: Frequency | null;
    installment_day: number;
    requested_activation_date: string | null;
    number_of_installments: number | null;
    start_date: string | null;
    end_date: string | null;
    next_installment_date: string | null;
    previous_installment_date: string | null;
    remaining_installments: number | null;
    state: string;
    auto_generate_installments: boolean;
    payment_method: string | null;
    payment_source: string | null;
    purpose: string | null;
    source_ref_id: string;
    partner: string | null;
    euin: string | null;
    user_ip: string | null;
    server_ip: string | null;
    initiated_by: string;
    initiated_via: string | null;
    created_at: string;
    activated_at: string | null;
    cancelled_at: string | null;
    cancellation_scheduled_on: string | null;
    failed_at: string | null;
    completed_at: string | null;
    reason: string | null;
    consent: Consent$3;
}
interface MfPurchasePlanCreateRequest {
    mf_investment_account: string;
    scheme: string;
    frequency: string;
    folio_number?: string;
    amount: number;
    installment_day?: number;
    number_of_installments?: number;
    systematic: boolean;
    payment_method?: string;
    payment_source?: string;
    purpose?: string;
    generate_first_installment_now?: boolean;
    auto_generate_installments?: boolean;
    activate_after?: string | null;
    initiated_by?: string;
    initiated_via?: string;
    euin?: string;
    user_ip?: string | null;
    server_ip?: string | null;
    source_ref_id?: string;
    partner?: string;
}
interface MfPurchasePlanUpdateRequest {
    id: string;
    amount?: number;
    scheme?: string;
    folio_number?: string;
    euin?: string;
    cancellation_scheduled_on?: string;
    payment_source?: string;
}
interface MfPurchasePlanFetchAllRequest {
    mf_investment_account?: string;
    states?: string;
    plan_basket?: string;
    skip_instruction?: string;
    plan?: string;
}

declare const mf_purchase_plan_types_d_mfPurchasePlanUrl: typeof mfPurchasePlanUrl;
type mf_purchase_plan_types_d_Frequency = Frequency;
type mf_purchase_plan_types_d_MfPurchasePlanObject = MfPurchasePlanObject;
type mf_purchase_plan_types_d_MfPurchasePlanCreateRequest = MfPurchasePlanCreateRequest;
type mf_purchase_plan_types_d_MfPurchasePlanUpdateRequest = MfPurchasePlanUpdateRequest;
type mf_purchase_plan_types_d_MfPurchasePlanFetchAllRequest = MfPurchasePlanFetchAllRequest;
declare namespace mf_purchase_plan_types_d {
  export {
    mf_purchase_plan_types_d_mfPurchasePlanUrl as mfPurchasePlanUrl,
    mf_purchase_plan_types_d_Frequency as Frequency,
    mf_purchase_plan_types_d_MfPurchasePlanObject as MfPurchasePlanObject,
    mf_purchase_plan_types_d_MfPurchasePlanCreateRequest as MfPurchasePlanCreateRequest,
    mf_purchase_plan_types_d_MfPurchasePlanUpdateRequest as MfPurchasePlanUpdateRequest,
    mf_purchase_plan_types_d_MfPurchasePlanFetchAllRequest as MfPurchasePlanFetchAllRequest,
  };
}

declare class MfPurchasePlanService {
    private api;
    constructor(api: Api);
    /**
     * Fetch a mf investment purchase plan
     * @param identifier V2 or V1 id of the purchase plan orde
     * @returns MfPurchasePlanObject
     **/
    fetch(identifier: string): Promise<MfPurchasePlanObject>;
    /**
     * FetchAll mf investment redemptions
     * @params MfPurchasePlanFetchAllRequest
     * @returns MfPurchasePlanObjects list
     **/
    fetchAll(params: MfPurchasePlanFetchAllRequest): Promise<ListResponse<MfPurchasePlanObject>>;
    /**
     * Create a mf investment purchase plan
     * @param MfPurchasePlanCreateRequest
     * @returns MfPurchasePlanObject
     **/
    create(data: MfPurchasePlanCreateRequest): Promise<MfPurchasePlanObject>;
    /**
     * Update a mf investment purchase plan
     * @param MfPurchasePlanUpdateRequest
     * @returns MfPurchasePlanObject
     **/
    update(data: MfPurchasePlanUpdateRequest): Promise<MfPurchasePlanObject>;
    /**
     * Cancel a mf investment purchase plan
     * @param identifier V2 or V1 id of the purchase plan orde
     * @returns MfPurchasePlanObject
     **/
    cancel(identifier: string): Promise<MfPurchasePlanObject>;
}

declare const mfRedemptionUrl = "/v2/mf_redemptions";
interface MfRedemptionObject {
    object: string;
    id: string;
    old_id: number;
    mf_investment_account: string;
    folio_number: string;
    state: string;
    amount: number | null;
    scheme: string;
    redemption_mode: string;
    traded_on: string | null;
    failed_at: string | null;
    plan: string | null;
    euin: string | null;
    distributor_id: string | null;
    units: number | null;
    redeemed_price: number | null;
    redeemed_units: number | null;
    redeemed_amount: number | null;
    redemption_bank_account_number: string | null;
    redemption_bank_account_ifsc_code: string | null;
    scheduled_on: string | null;
    created_at: string;
    confirmed_at: string | null;
    succeeded_at: string | null;
    submitted_at: string | null;
    reversed_at: string | null;
    gateway: string;
    initiated_by: string;
    initiated_via: string | null;
    source_ref_id: string;
    user_ip: string | null;
    server_ip: string | null;
    partner: string | null;
    failure_code: string | null;
    retried_at: string | null;
}
interface MfRedemptionCreateRequest {
    mf_investment_account: string;
    scheme: string;
    folio_number: string;
    amount?: number;
    units?: null | number;
    user_ip?: string | null;
    server_ip?: string | null;
    source_ref_id?: string;
    euin?: string | null;
}
interface MfRedemptionUpdateRequest {
    id: string;
    state: string;
    consent?: {
        email?: string;
        isd_code?: string;
        mobile?: string;
    };
}
interface MfRedemptionFetchAllRequest {
    mf_investment_account?: string;
    plan_basket?: string;
    skip_instruction?: string;
    plan?: string;
    states?: string;
}

declare const mf_redemption_types_d_mfRedemptionUrl: typeof mfRedemptionUrl;
type mf_redemption_types_d_MfRedemptionObject = MfRedemptionObject;
type mf_redemption_types_d_MfRedemptionCreateRequest = MfRedemptionCreateRequest;
type mf_redemption_types_d_MfRedemptionUpdateRequest = MfRedemptionUpdateRequest;
type mf_redemption_types_d_MfRedemptionFetchAllRequest = MfRedemptionFetchAllRequest;
declare namespace mf_redemption_types_d {
  export {
    mf_redemption_types_d_mfRedemptionUrl as mfRedemptionUrl,
    mf_redemption_types_d_MfRedemptionObject as MfRedemptionObject,
    mf_redemption_types_d_MfRedemptionCreateRequest as MfRedemptionCreateRequest,
    mf_redemption_types_d_MfRedemptionUpdateRequest as MfRedemptionUpdateRequest,
    mf_redemption_types_d_MfRedemptionFetchAllRequest as MfRedemptionFetchAllRequest,
  };
}

declare class MfRedemptionService {
    private api;
    constructor(api: Api);
    /**
     * Fetch a mf investment redemption
     * @param identifier V2 or V1 id of the redemption orde
     * @returns MfRedemptionObject
     **/
    fetch(identifier: string): Promise<MfRedemptionObject>;
    /**
     * FetchAll mf investment redemptions
     * @params MfRedemptionFetchAllRequest
     * @returns MfRedemptionObjects list
     **/
    fetchAll(params: MfRedemptionFetchAllRequest): Promise<ListResponse<MfRedemptionObject>>;
    /**
     * Create a mf investment redemption
     * @param MfRedemptionCreateRequest
     * @returns MfRedemptionObject
     **/
    create(data: MfRedemptionCreateRequest): Promise<MfRedemptionObject>;
    /**
     * Update a mf investment redemption
     * @param MfRedemptionUpdateRequest
     * @returns MfRedemptionObject
     **/
    update(data: MfRedemptionUpdateRequest): Promise<MfRedemptionObject>;
}

declare const mfRedemptionPlanUrl = "/v2/mf_redemption_plans";
interface Consent$2 {
    email?: string;
    isd_code?: string;
    mobile?: string;
}
interface MfRedemptionPlanCreateRequest {
    mf_investment_account: string;
    scheme: string;
    frequency: string;
    folio_number: string;
    amount: number;
    installment_day?: number;
    number_of_installments?: number | null;
    systematic?: string;
    generate_first_installment_now?: boolean;
    auto_generate_installments?: boolean;
    activate_after?: string;
    initiated_by?: string | null;
    initiated_via?: string | null;
    euin?: string | null;
    user_ip?: string | null;
    server_ip?: string | null;
    source_ref_id?: string;
    consent: Consent$2;
}
interface MfRedemptionPlanUpdateRequest {
    id: string;
    amount?: number;
    scheme?: string;
    folio_number?: string;
    euin?: string;
    cancellation_scheduled_on?: string;
}
interface MfRedemptionPlanFetchAllRequest {
    mf_investment_account?: string;
    states?: string;
}
interface MfRedemptionPlanObject {
    object: string;
    id: string;
    mf_investment_account: string;
    folio_number: string;
    scheme: string;
    amount: number;
    systematic: boolean;
    frequency: string;
    installment_day: number | null;
    requested_activation_date: string | null;
    number_of_installments: number;
    start_date: string;
    end_date: string;
    next_installment_date: string;
    previous_installment_date: string;
    remaining_installments: string | null;
    state: string;
    auto_generate_installments: boolean;
    source_ref_id: string;
    partner: string;
    gateway: number | null;
    euin: string;
    user_ip: string | null;
    server_ip: string | null;
    initiated_by: string | null;
    initiated_via: string | null;
    created_at: string;
    activated_at: string;
    cancelled_at: string;
    cancellation_scheduled_on: string | null;
    failed_at: string | null;
    completed_at: string | null;
    reason: string | null;
    consent: Consent$2;
}

declare const mf_redemption_plan_types_d_mfRedemptionPlanUrl: typeof mfRedemptionPlanUrl;
type mf_redemption_plan_types_d_MfRedemptionPlanCreateRequest = MfRedemptionPlanCreateRequest;
type mf_redemption_plan_types_d_MfRedemptionPlanUpdateRequest = MfRedemptionPlanUpdateRequest;
type mf_redemption_plan_types_d_MfRedemptionPlanFetchAllRequest = MfRedemptionPlanFetchAllRequest;
type mf_redemption_plan_types_d_MfRedemptionPlanObject = MfRedemptionPlanObject;
declare namespace mf_redemption_plan_types_d {
  export {
    mf_redemption_plan_types_d_mfRedemptionPlanUrl as mfRedemptionPlanUrl,
    mf_redemption_plan_types_d_MfRedemptionPlanCreateRequest as MfRedemptionPlanCreateRequest,
    mf_redemption_plan_types_d_MfRedemptionPlanUpdateRequest as MfRedemptionPlanUpdateRequest,
    mf_redemption_plan_types_d_MfRedemptionPlanFetchAllRequest as MfRedemptionPlanFetchAllRequest,
    mf_redemption_plan_types_d_MfRedemptionPlanObject as MfRedemptionPlanObject,
  };
}

declare class MfRedemptionPlanService {
    private api;
    constructor(api: Api);
    /**
     * Fetch a mf_redemption_plan
     * @param id of the redemption plan.
     * @returns MfRedemptionPlanObject
     */
    fetch(id: string): Promise<MfRedemptionPlanObject>;
    /**
     * This API used to fetch all mf_redemption_plans with a limit of 100.
     * @returns MfRedemptionPlanObjects list
     */
    fetchAll(params: MfRedemptionPlanFetchAllRequest): Promise<ListResponse<MfRedemptionPlanObject>>;
    /**
     * Create an mf_redemption_plan
     * @param data MfRedemptionPlanCreateRequest object
     * @returns MfRedemptionPlanObject
     */
    create(data: MfRedemptionPlanCreateRequest): Promise<MfRedemptionPlanObject>;
    /**
     * Update the mf_redemption_plan
     * @param data MfRedemptionPlanUpdateRequest
     * @returns MfRedemptionPlanObject
     */
    update(data: MfRedemptionPlanUpdateRequest): Promise<MfRedemptionPlanObject>;
    /**
     * Cancel a mf redemption plan
     * @param identifier id of the redemption plan
     * @returns MfRedemptionPlanObject
     **/
    cancel(identifier: string): Promise<MfRedemptionPlanObject>;
}

declare const mfSettlementDetailsUrl = "/v2/mf_settlement_details";
interface MfSettlementDetailCreateRequest {
    mf_purchase: string;
    payment_type: string;
    utr_number?: string;
    bank_account_number: string;
    bank_ifsc: string;
    beneficiary_account_number: string;
    beneficiary_account_title: string;
    beneficiary_bank_name: string;
    settlement_processed_at?: string;
}
interface MfSettlementDetailPatchRequest {
    id: string;
    utr_number: string;
    settlement_processed_at: string;
}
interface MfSettlementDetailFetchAllRequest {
    mf_purchase: string;
}
interface MfSettlementDetailObject {
    object: string;
    id: string;
    mf_purchase: string;
    utr_number: string;
    bank_account_number: string;
    bank_ifsc: string;
    bank_name: string;
    bank_account_type: string;
    payment_type: string;
    beneficiary_account_number: string;
    beneficiary_account_title: string;
    beneficiary_bank_name: string;
    settlement_processed_at: string;
}

declare const mf_settlement_detail_types_d_mfSettlementDetailsUrl: typeof mfSettlementDetailsUrl;
type mf_settlement_detail_types_d_MfSettlementDetailCreateRequest = MfSettlementDetailCreateRequest;
type mf_settlement_detail_types_d_MfSettlementDetailPatchRequest = MfSettlementDetailPatchRequest;
type mf_settlement_detail_types_d_MfSettlementDetailFetchAllRequest = MfSettlementDetailFetchAllRequest;
type mf_settlement_detail_types_d_MfSettlementDetailObject = MfSettlementDetailObject;
declare namespace mf_settlement_detail_types_d {
  export {
    mf_settlement_detail_types_d_mfSettlementDetailsUrl as mfSettlementDetailsUrl,
    mf_settlement_detail_types_d_MfSettlementDetailCreateRequest as MfSettlementDetailCreateRequest,
    mf_settlement_detail_types_d_MfSettlementDetailPatchRequest as MfSettlementDetailPatchRequest,
    mf_settlement_detail_types_d_MfSettlementDetailFetchAllRequest as MfSettlementDetailFetchAllRequest,
    mf_settlement_detail_types_d_MfSettlementDetailObject as MfSettlementDetailObject,
  };
}

declare class MfSettlementDetailService {
    private api;
    constructor(api: Api);
    /**
     * Fetch a MF Switch
     * @param id V2 id of the settlement detail.
     * @returns MfSettlementDetailObject
     */
    fetch(id: string): Promise<MfSettlementDetailObject>;
    /**
     * This API used to fetch all settlement details with a limit of 100.
     * @returns MfSettlementDetailObject list
     */
    fetchAll(params: MfSettlementDetailFetchAllRequest): Promise<MfSettlementDetailObject>;
    /**
     * Create an settlement detail
     * @param data MfSettlementDetailCreateRequest object
     * @returns MfSettlementDetailObject
     */
    create(data: MfSettlementDetailCreateRequest): Promise<MfSettlementDetailObject>;
    /**
     * update the settlement detail
     * @param data MfSettlementDetailPatchRequest
     * @returns MfSettlementDetailObject
     */
    update(data: MfSettlementDetailPatchRequest): Promise<MfSettlementDetailObject>;
}

declare const mfSwitchUrl = "/v2/mf_switches";
interface MfSwitchCreateRequest {
    mf_investment_account: string;
    folio_number: string;
    switch_out_scheme: string;
    switch_in_scheme: string;
    amount?: number | string;
    units?: number | null;
    user_ip?: string;
    server_ip?: string;
    source_ref_id?: string;
    euin?: string | null;
}
interface Consent$1 {
    email?: string;
    isd_code?: string;
    mobile?: string;
}
interface MfSwitchPatchRequest {
    id: string;
    state: string;
    consent: Consent$1;
}
interface MfSwitchFetchAllRequest {
    mf_investment_account?: string;
    plan_basket?: string;
    skip_instruction?: string;
    plan?: string;
    states?: string;
}
interface MfSwitchObject {
    object: string;
    id: string;
    old_id: number;
    mf_investment_account: string;
    folio_number: string;
    state: string;
    amount: number;
    units: number | null;
    switch_out_scheme: string;
    switch_in_scheme: string | null;
    plan: string | null;
    switched_out_units: number | null;
    switched_out_amount: number | null;
    switched_out_price: number | null;
    switched_in_units: number | null;
    switched_in_amount: number | null;
    switched_in_price: number | null;
    scheduled_on: string;
    traded_on: string | null;
    created_at: string;
    confirmed_at: string;
    submitted_at: string;
    succeeded_at: string | null;
    failed_at: string | null;
    reversed_at: string | null;
    gateway: number | null;
    source_ref_id: string | null;
    user_ip: string | null;
    server_ip: string | null;
    euin: string | null;
    partner: string | null;
    failure_code: string | null;
    initiated_by: string | null;
    initiated_via: string | null;
}

declare const mf_switch_types_d_mfSwitchUrl: typeof mfSwitchUrl;
type mf_switch_types_d_MfSwitchCreateRequest = MfSwitchCreateRequest;
type mf_switch_types_d_MfSwitchPatchRequest = MfSwitchPatchRequest;
type mf_switch_types_d_MfSwitchFetchAllRequest = MfSwitchFetchAllRequest;
type mf_switch_types_d_MfSwitchObject = MfSwitchObject;
declare namespace mf_switch_types_d {
  export {
    mf_switch_types_d_mfSwitchUrl as mfSwitchUrl,
    mf_switch_types_d_MfSwitchCreateRequest as MfSwitchCreateRequest,
    mf_switch_types_d_MfSwitchPatchRequest as MfSwitchPatchRequest,
    mf_switch_types_d_MfSwitchFetchAllRequest as MfSwitchFetchAllRequest,
    mf_switch_types_d_MfSwitchObject as MfSwitchObject,
  };
}

declare class MfSwitchService {
    private api;
    constructor(api: Api);
    /**
     * Fetch a MF Switch
     * @param id V2 or V1 id of the switch order.
     * @returns MfSwitchObject
     */
    fetch(id: string): Promise<MfSwitchObject>;
    /**
     * This API used to fetch all mf_switches with a limit of 100.
     * @returns MfSwitchObjects list
     */
    fetchAll(params: MfSwitchFetchAllRequest): Promise<ListResponse<MfSwitchObject>>;
    /**
     * Create an mf_switch
     * @param data MfSwitchCreateRequest object
     * @returns MfSwitchObject
     */
    create(data: MfSwitchCreateRequest): Promise<MfSwitchObject>;
    /**
     * Update the mf_switch
     * @param data MfSwitchPatchRequest
     * @returns MfSwitchObject
     */
    update(data: MfSwitchPatchRequest): Promise<MfSwitchObject>;
}

interface Consent {
    email?: string;
    isd_code?: string;
    mobile?: string;
}
declare const mfSwitchPlanUrl = "/v2/mf_switch_plans";
interface MfSwitchPlanObject {
    object: string;
    id: string;
    mf_investment_account: string;
    folio_number: string | null;
    switch_out_scheme: string;
    switch_in_scheme: string;
    amount: number;
    systematic: boolean;
    frequency: string;
    installment_day: number | null;
    requested_activation_date: string | null;
    number_of_installments: number;
    start_date: string | null;
    end_date: string | null;
    next_installment_date: string | null;
    previous_installment_date: string | null;
    remaining_installments: number | null;
    state: string;
    auto_generate_installments: boolean;
    source_ref_id: string | null;
    partner: string;
    gateway: number;
    euin: string | null;
    user_ip: string | null;
    server_ip: string | null;
    initiated_by: string | null;
    initiated_via: string | null;
    created_at: string;
    activated_at: string | null;
    cancelled_at: string | null;
    cancellation_scheduled_on: string | null;
    failed_at: string | null;
    completed_at: string | null;
    reason: string | null;
    consent: Consent;
}
interface MfSwitchPlanCreateRequest {
    mf_investment_account: string;
    switch_out_scheme: string;
    switch_in_scheme: string;
    frequency: string;
    folio_number: string;
    amount: number;
    installment_day?: number;
    number_of_installments?: number;
    systematic: boolean;
    generate_first_installment_now?: boolean;
    auto_generate_installments?: boolean;
    activate_after?: string;
    initiated_by?: string;
    initiated_via?: string;
    euin?: string;
    user_ip?: string;
    server_ip?: string;
    source_ref_id?: string;
    consent: Consent;
}
interface MfSwitchPlanUpdateRequest {
    id: string;
    amount?: number;
    scheme_out_scheme?: string;
    scheme_in_scheme?: string;
    folio_number?: string;
    euin?: string;
    cancellation_scheduled_on?: string;
}
interface MfSwitchPlanFetchAllRequest {
    mf_investment_account?: string;
    states?: string;
}

declare const mf_switch_plan_types_d_mfSwitchPlanUrl: typeof mfSwitchPlanUrl;
type mf_switch_plan_types_d_MfSwitchPlanObject = MfSwitchPlanObject;
type mf_switch_plan_types_d_MfSwitchPlanCreateRequest = MfSwitchPlanCreateRequest;
type mf_switch_plan_types_d_MfSwitchPlanUpdateRequest = MfSwitchPlanUpdateRequest;
type mf_switch_plan_types_d_MfSwitchPlanFetchAllRequest = MfSwitchPlanFetchAllRequest;
declare namespace mf_switch_plan_types_d {
  export {
    mf_switch_plan_types_d_mfSwitchPlanUrl as mfSwitchPlanUrl,
    mf_switch_plan_types_d_MfSwitchPlanObject as MfSwitchPlanObject,
    mf_switch_plan_types_d_MfSwitchPlanCreateRequest as MfSwitchPlanCreateRequest,
    mf_switch_plan_types_d_MfSwitchPlanUpdateRequest as MfSwitchPlanUpdateRequest,
    mf_switch_plan_types_d_MfSwitchPlanFetchAllRequest as MfSwitchPlanFetchAllRequest,
  };
}

declare class MfSwitchPlanService {
    private api;
    constructor(api: Api);
    /**
     * Create an mf_switch_plan
     * @param data MfSwitchPlanCreateRequest object
     * @returns MfSwitchPlanObject
     */
    create(data: MfSwitchPlanCreateRequest): Promise<MfSwitchPlanObject>;
    /**
     * Update the mf_switch_plans
     * @param data MfSwitchPlanPatchRequest
     * @returns MfSwitchPlanObject
     */
    update(data: MfSwitchPlanUpdateRequest): Promise<MfSwitchPlanObject>;
    /**
     * Fetch a mf_switch_plan
     * @param id of the switch plan.
     * @returns MfSwitchPlanObject
     */
    fetch(id: string): Promise<MfSwitchPlanObject>;
    /**
     * This API used to fetch all mf_switch_plans.
     * @returns MfSwitchPlanObjects list
     */
    fetchAll(params: MfSwitchPlanFetchAllRequest): Promise<ListResponse<MfSwitchPlanObject>>;
    /**
     * Cancel a mf switch plan
     * @param identifier id of the mf switch plan
     * @returns MfSwitchPlanObject
     **/
    cancel(identifier: string): Promise<MfSwitchPlanObject>;
}

declare const transactionReportsUrl = "/v2/transactions/reports";
declare const investorReportUrl = "/v2/investors/reports";
declare const mfPurchaseReportUrl = "/v2/mf_purchases/reports";
declare const mfRedemptionReportUrl = "/v2/mf_redemptions/reports";
interface Report {
    type: string;
    standard: {
        name: string;
        desc: string;
    };
}
interface Data {
    rows: (string | number)[];
    columns: string[];
}
interface FilterByRequest {
    partner: string;
    traded_on_from: string;
    traded_on_to: string;
}
interface ReportResponse {
    object: string;
    report: Report;
    data: Data;
    filter_by: FilterByRequest;
}
interface InvestorListReportRequest {
    partner: string;
}
interface PurchaseListReportRequest {
    ids?: string[];
    states?: string[];
    plans?: string[];
    plan_old_ids?: string[];
}
interface RedemptionListReportRequest extends PurchaseListReportRequest {
}

declare const other_report_types_d_transactionReportsUrl: typeof transactionReportsUrl;
declare const other_report_types_d_investorReportUrl: typeof investorReportUrl;
declare const other_report_types_d_mfPurchaseReportUrl: typeof mfPurchaseReportUrl;
declare const other_report_types_d_mfRedemptionReportUrl: typeof mfRedemptionReportUrl;
type other_report_types_d_FilterByRequest = FilterByRequest;
type other_report_types_d_ReportResponse = ReportResponse;
type other_report_types_d_InvestorListReportRequest = InvestorListReportRequest;
type other_report_types_d_PurchaseListReportRequest = PurchaseListReportRequest;
type other_report_types_d_RedemptionListReportRequest = RedemptionListReportRequest;
declare namespace other_report_types_d {
  export {
    other_report_types_d_transactionReportsUrl as transactionReportsUrl,
    other_report_types_d_investorReportUrl as investorReportUrl,
    other_report_types_d_mfPurchaseReportUrl as mfPurchaseReportUrl,
    other_report_types_d_mfRedemptionReportUrl as mfRedemptionReportUrl,
    other_report_types_d_FilterByRequest as FilterByRequest,
    other_report_types_d_ReportResponse as ReportResponse,
    other_report_types_d_InvestorListReportRequest as InvestorListReportRequest,
    other_report_types_d_PurchaseListReportRequest as PurchaseListReportRequest,
    other_report_types_d_RedemptionListReportRequest as RedemptionListReportRequest,
  };
}

declare class OtherReportService {
    private api;
    constructor(api: Api);
    /**
     * This report groups the transactions by their type and provides the consolidated amount against each such transaction type
     * @param FilterByRequest
     * @returns ReportResponse
     **/
    fetch_transaction_type_wise_amount_summary(params: Partial<FilterByRequest>): Promise<ReportResponse>;
    /**
     * This report groups provides the AUM for each fund category
     * @param FilterByRequest
     * @returns ReportResponse
     **/
    fund_scheme_category_wise_aum_summary(params: Partial<FilterByRequest>): Promise<ReportResponse>;
    /**
     * This report lists the transactions.
     * @param FilterByRequest
     * @returns ReportResponse
     **/
    transaction_list(params: Partial<FilterByRequest>): Promise<ReportResponse>;
    /**
     * This report lists the investors.
     * @param InvestorListReportRequest
     * @returns ReportResponse
     **/
    investor_list(params: Partial<InvestorListReportRequest>): Promise<ReportResponse>;
    /**
     * This report lists mf_purchases.
     * @param PurchaseListReportRequest
     * @returns ReportResponse
     **/
    mf_purchase_list(params: Partial<PurchaseListReportRequest>): Promise<ReportResponse>;
    /**
     * This report lists mf_redemptions.
     * @param RedemptionListReportRequest
     * @returns ReportResponse
     **/
    mf_redemption_list(params: Partial<RedemptionListReportRequest>): Promise<ReportResponse>;
}

declare const partnerUrl = "/v2/partners";
interface PartnerObject {
    object: string;
    id: string;
    name: string | null;
    license_code: string | null;
    created_at: string | null;
    default_broker_codes: {
        cams?: string;
        karvy?: string;
    } | null;
    location: string;
    ref_no: string | null;
    mobile: string | null;
    email: string | null;
    contact_person_name: string | null;
    expiry_date: string | null;
    euins: string[] | null;
    display_name: string | null;
}
interface PartnerCreateRequest {
    default_broker_codes: {
        cams: string;
        karvy: string;
    };
    location: string;
    name: string;
    license_code: string;
    ref_no?: string;
    mobile?: string;
    email?: string;
    contact_person_name?: string;
    expiry_date?: string;
    euins?: string[];
}
interface PartnerSearchRequest {
    code: string;
}

declare const partner_types_d_partnerUrl: typeof partnerUrl;
type partner_types_d_PartnerObject = PartnerObject;
type partner_types_d_PartnerCreateRequest = PartnerCreateRequest;
type partner_types_d_PartnerSearchRequest = PartnerSearchRequest;
declare namespace partner_types_d {
  export {
    partner_types_d_partnerUrl as partnerUrl,
    partner_types_d_PartnerObject as PartnerObject,
    partner_types_d_PartnerCreateRequest as PartnerCreateRequest,
    partner_types_d_PartnerSearchRequest as PartnerSearchRequest,
  };
}

declare class PartnerService {
    private api;
    constructor(api: Api);
    /**
     * Fetch an Partner
     * @param id string
     * @returns PartnerObject
     **/
    fetchById(id: string): Promise<PartnerObject>;
    /**
     * Fetch an Partner
     * @returns  List of PartnerObject
     **/
    fetchAll(): Promise<ListResponse<PartnerObject>>;
    /**
     * Create a Partner
     * @param  {Partner.PartnerCreateRequest} data PartnerCreateRequest object
     * @returns {PartnerObject.PartnerCreateRequest} PartnerObject
     **/
    create(data: PartnerCreateRequest): Promise<PartnerObject>;
    /**
     * Search Partner
     * @returns PartnerObject
     **/
    search(params: PartnerSearchRequest): Promise<ListResponse<PartnerObject>>;
}

declare const paymentUrl = "/api/pg/payments";
interface PaymentObject {
    payment_type: string | null;
    status: string | null;
    amount: number | null;
    debit_date: string | null;
    amc_order_ids: number[];
    failed_reason: string | null;
    method: string | null;
    created_at: string | null;
    submitted_at: string | null;
    debit_confirmed_at: string | null;
    failed_at: string | null;
    transfer_initiated_at: string | null;
    settled_at: string | null;
    rejected_at: string | null;
    from_bank_account_id: number | null;
    provider_name: string | null;
    failure_code: string | null;
    late_auth: boolean | null;
    refund_reference: string | null;
    refund_reason: string | null;
    refund_status: string | null;
    refund_created_at: string | null;
    id: number;
}
interface PaymentCreateResponse {
    token_url: string;
    id: number;
}
interface PaymentCreateRequest {
    amc_order_ids: number[];
    method?: string;
    payment_postback_url?: string;
    bank_account_id?: number;
}
interface PaymentCreateNachRequest {
    mandate_id: number;
    amc_order_ids: number[];
}
interface PaymentCreateNachResponse {
    id: number;
    mandate_id: number;
    amount: number;
    amc_order_ids: number[];
}
interface PaymentFetchAllRequest {
    from?: string;
    to?: string;
    payment_type?: string;
    payment_status?: string;
    amc_order_ids?: string;
    direction?: string;
    page?: number;
    size?: number;
}
interface PaymentFetchAllResponse {
    last: boolean;
    total_pages: number;
    total_elements: number;
    size: number;
    number: number;
    first: boolean;
    number_of_elements: number;
    payments: PaymentObject[];
}
interface PostPaymentVerificationRequest {
    payment_id: string;
    status: string;
    failure_reason: string | null;
    hash: string;
    tenant: string;
}
interface PostPaymentVerificationResponse {
    status: string | null;
    payment_id: string | null;
}
interface PostPaymentVerificationErrorResponse {
    error: {
        status: number;
        message: string;
    };
}

declare const payment_types_d_paymentUrl: typeof paymentUrl;
type payment_types_d_PaymentObject = PaymentObject;
type payment_types_d_PaymentCreateResponse = PaymentCreateResponse;
type payment_types_d_PaymentCreateRequest = PaymentCreateRequest;
type payment_types_d_PaymentCreateNachRequest = PaymentCreateNachRequest;
type payment_types_d_PaymentCreateNachResponse = PaymentCreateNachResponse;
type payment_types_d_PaymentFetchAllRequest = PaymentFetchAllRequest;
type payment_types_d_PaymentFetchAllResponse = PaymentFetchAllResponse;
type payment_types_d_PostPaymentVerificationRequest = PostPaymentVerificationRequest;
type payment_types_d_PostPaymentVerificationResponse = PostPaymentVerificationResponse;
type payment_types_d_PostPaymentVerificationErrorResponse = PostPaymentVerificationErrorResponse;
declare namespace payment_types_d {
  export {
    payment_types_d_paymentUrl as paymentUrl,
    payment_types_d_PaymentObject as PaymentObject,
    payment_types_d_PaymentCreateResponse as PaymentCreateResponse,
    payment_types_d_PaymentCreateRequest as PaymentCreateRequest,
    payment_types_d_PaymentCreateNachRequest as PaymentCreateNachRequest,
    payment_types_d_PaymentCreateNachResponse as PaymentCreateNachResponse,
    payment_types_d_PaymentFetchAllRequest as PaymentFetchAllRequest,
    payment_types_d_PaymentFetchAllResponse as PaymentFetchAllResponse,
    payment_types_d_PostPaymentVerificationRequest as PostPaymentVerificationRequest,
    payment_types_d_PostPaymentVerificationResponse as PostPaymentVerificationResponse,
    payment_types_d_PostPaymentVerificationErrorResponse as PostPaymentVerificationErrorResponse,
  };
}

declare class PaymentService {
    private api;
    constructor(api: Api);
    /**
     * Create a payment
     * @param data PaymentCreateRequest
     * @returns PaymentCreateResponse
     */
    createNetbankingPayment(data: PaymentCreateRequest): Promise<PaymentCreateResponse>;
    /**
     * Create a payment nach
     * @param data PaymentCreateRequest
     * @returns PaymentCreateResponse
     */
    createNachPayment(data: PaymentCreateNachRequest): Promise<PaymentCreateNachResponse>;
    /**
     * Fetch a Payment
     * @param id payment.
     * @returns PaymentFetchResponse
     */
    fetch(id: number): Promise<PaymentObject>;
    /**
     * This API used to fetch all payments with a limit of 100.
     * @returns PaymentFetchAllResponse
     */
    fetchAll(params: PaymentFetchAllRequest): Promise<PaymentFetchAllResponse>;
    /**
     * This method is used to check for the status post payment,
     * it verifies if the data passed was tampered or not
     * @param Payment.PostPaymentVerificationRequest
     * @returns Payment.PostPaymentVerificationResponse | Payment.PostPaymentVerificationErrorResponse
     */
    postBackVerification(params: PostPaymentVerificationRequest): Promise<PostPaymentVerificationResponse | PostPaymentVerificationErrorResponse>;
}

declare const FP_DASHBOARD_BASE_URL = "/api/pg";
interface GetPaymentsGetwayResponse {
    object: "pg_tenant";
    domain: string;
    legal_name: string;
    display_name: string;
    default_payment_gateway: string;
    providers: string[];
    capabilities: {
        upi_auto_pay: {
            bse: boolean;
            razorpay: boolean;
            billdesk: boolean;
        };
        e_nach_mandate: {
            bse: boolean;
            razorpay: boolean;
            billdesk: boolean;
        };
        payment: {
            bse: boolean;
            razorpay: boolean;
            billdesk: boolean;
        };
    };
    default_payment_postback_url: string;
    default_emandate_auth_postback_url: string;
    id: string;
}
interface GetGatewayDetailsRequestObject {
    gateway: string;
}
interface AddBilldeskGatewayRequest {
    gateway: string;
    data: {
        v1?: {
            merchant_id: string;
            checksum_key: string;
            upi_bank_id: string;
            allow_netbanking_upi: boolean;
        };
        v2?: {
            merchant_id: string;
            client_id: string;
            allow_netbanking_upi: boolean;
        };
    };
}
interface BilldeskGatewayDetailsResponse {
    object: "billdesk";
    id: string;
    payment: boolean;
    payment_transfer: boolean;
    upi_auto_pay: boolean;
    billdesk: {
        V1: {
            allow_netbanking_upi: boolean;
            checksum_key: string;
            merchant_id: string;
            upi_bank_id: string;
        };
        V2: {
            allow_netbanking_upi: boolean;
            merchant_id: string;
            client_id: string;
        };
    };
    webhook: {
        url: string;
    };
    e_nach_mandate: boolean;
}
interface BSEGatewayDetailsResponse {
    object: "bse";
    id: string;
    payment: boolean;
    payment_transfer: boolean;
    upi_auto_pay: boolean;
    e_nach_mandate: boolean;
}
interface AddRazorpayGatewayRequest {
    gateway: string;
    data: {
        api_key: string;
        secret_key: string;
        tpv_api_key: string;
        tpv_secret_key: string;
        payment_transfer: boolean;
    };
}
interface RazorpayGatewayDetailsResponse {
    object: "razorpay";
    id: string;
    payment: boolean;
    payment_transfer: boolean;
    upi_auto_pay: boolean;
    razorpay: {
        tpv_secret_key: string;
        secret_key: string;
        api_key: string;
        tpv_api_key: string;
    };
    webhook: {
        url: string;
        token: string;
    };
    e_nach_mandate: boolean;
}
interface IGatewayUpdateRequestObject {
    gateway: string;
    razorpay_data: {
        api_key: string;
        secret_key: string;
        tpv_api_key: string;
        tpv_secret_key: string;
    } | null;
    billdesk_data: {
        v1?: {
            merchant_id: string;
            checksum_key: string;
            upi_bank_id: string;
            allow_netbanking_upi: boolean;
        };
        v2?: {
            merchant_id: string;
            client_id: string;
            allow_netbanking_upi: boolean;
        };
    } | null;
}
interface PgTenantSetupObject {
    legal_name: string | undefined;
    display_name: string | undefined;
    payment_postback_url: string | undefined;
    emandate_postback_url: string | undefined;
}
declare type PaymentMethods = "UPI" | "NETBANKING" | "EMANDATE";
interface AddPgAmcRequest {
    amc_id: number;
    bank_name: string;
    ifsc_code: string;
    account_number: string;
    account_holder_name: string;
    provider_name: "RAZORPAY" | "BILLDESK";
    payment_methods: PaymentMethods[];
    source_bank_ifsc_identifier?: string;
    razorpay?: {
        razorpay_bank_account_id: string;
    };
    billdesk?: {
        billdesk_child_merchant_id: string;
    };
}
interface PgAmcBeneficiaryBankDetailsResponse {
    object: string;
    amc_id: number;
    provider_name: "RAZORPAY" | "BILLDESK";
    bank_name: string;
    account_holder_name: string;
    account_number: string;
    ifsc_code: string;
    payment_methods: PaymentMethods[];
    source_bank_ifsc_identifier?: string;
    razorpay?: {
        razorpay_bank_account_id: string;
    };
    billdesk?: {
        billdesk_child_merchant_id: string;
    };
    id: string;
}
interface UPIAutopayRequestObject {
    razorpay_upi_mandate_enabled?: boolean;
    billdesk_upi_mandate_enabled?: boolean;
}
interface UPIAutopayResponseObject {
    razorpay_upi_mandate_enabled: boolean;
}

declare const payments_gateway_types_d_FP_DASHBOARD_BASE_URL: typeof FP_DASHBOARD_BASE_URL;
type payments_gateway_types_d_GetPaymentsGetwayResponse = GetPaymentsGetwayResponse;
type payments_gateway_types_d_GetGatewayDetailsRequestObject = GetGatewayDetailsRequestObject;
type payments_gateway_types_d_AddBilldeskGatewayRequest = AddBilldeskGatewayRequest;
type payments_gateway_types_d_BilldeskGatewayDetailsResponse = BilldeskGatewayDetailsResponse;
type payments_gateway_types_d_BSEGatewayDetailsResponse = BSEGatewayDetailsResponse;
type payments_gateway_types_d_AddRazorpayGatewayRequest = AddRazorpayGatewayRequest;
type payments_gateway_types_d_RazorpayGatewayDetailsResponse = RazorpayGatewayDetailsResponse;
type payments_gateway_types_d_IGatewayUpdateRequestObject = IGatewayUpdateRequestObject;
type payments_gateway_types_d_PgTenantSetupObject = PgTenantSetupObject;
type payments_gateway_types_d_AddPgAmcRequest = AddPgAmcRequest;
type payments_gateway_types_d_PgAmcBeneficiaryBankDetailsResponse = PgAmcBeneficiaryBankDetailsResponse;
type payments_gateway_types_d_UPIAutopayRequestObject = UPIAutopayRequestObject;
type payments_gateway_types_d_UPIAutopayResponseObject = UPIAutopayResponseObject;
declare namespace payments_gateway_types_d {
  export {
    payments_gateway_types_d_FP_DASHBOARD_BASE_URL as FP_DASHBOARD_BASE_URL,
    payments_gateway_types_d_GetPaymentsGetwayResponse as GetPaymentsGetwayResponse,
    payments_gateway_types_d_GetGatewayDetailsRequestObject as GetGatewayDetailsRequestObject,
    payments_gateway_types_d_AddBilldeskGatewayRequest as AddBilldeskGatewayRequest,
    payments_gateway_types_d_BilldeskGatewayDetailsResponse as BilldeskGatewayDetailsResponse,
    payments_gateway_types_d_BSEGatewayDetailsResponse as BSEGatewayDetailsResponse,
    payments_gateway_types_d_AddRazorpayGatewayRequest as AddRazorpayGatewayRequest,
    payments_gateway_types_d_RazorpayGatewayDetailsResponse as RazorpayGatewayDetailsResponse,
    payments_gateway_types_d_IGatewayUpdateRequestObject as IGatewayUpdateRequestObject,
    payments_gateway_types_d_PgTenantSetupObject as PgTenantSetupObject,
    payments_gateway_types_d_AddPgAmcRequest as AddPgAmcRequest,
    payments_gateway_types_d_PgAmcBeneficiaryBankDetailsResponse as PgAmcBeneficiaryBankDetailsResponse,
    payments_gateway_types_d_UPIAutopayRequestObject as UPIAutopayRequestObject,
    payments_gateway_types_d_UPIAutopayResponseObject as UPIAutopayResponseObject,
  };
}

declare class PaymentsGatewayService {
    private api;
    constructor(api: Api);
    /**
     * Fetch payments gateway details
     * @returns GetPaymentsGetwayResponse
     **/
    fetchAll(): Promise<GetPaymentsGetwayResponse>;
    setupTenant(tenantDetails: PgTenantSetupObject): Promise<GetPaymentsGetwayResponse>;
    updateTenantDetails(tenantDetails: PgTenantSetupObject): Promise<GetPaymentsGetwayResponse>;
    /**
     * Fetch individual payment gateway details
     * @param Payment gateway for which details needs to be fetched
     * @returns GetGatewayDetailsRequestObject
     **/
    fetchGateway(GetGatewayDetailsRequestObject: GetGatewayDetailsRequestObject): Promise<RazorpayGatewayDetailsResponse | BilldeskGatewayDetailsResponse | BSEGatewayDetailsResponse>;
    /**
     * Updates individual payment gateway's details
     * @param gateway  gateway for which details needs to be udpated
     * @param razorpay_data  Razorpay gateway updated data
     * @returns RazorpayGatewayDetailsResponse or BilldeskGatewayDetailsResponse
     **/
    updateGateway(GatewayUpdateRequestObject: IGatewayUpdateRequestObject): Promise<RazorpayGatewayDetailsResponse | BilldeskGatewayDetailsResponse>;
    /**
     * Add a payment gateway
     * @param gateway  gateway for which details needs to be added
     * @param data  Razorpay or Billdesk gateway data
     * @returns RazorpayGatewayDetailsResponse or BilldeskGatewayDetailsResponse
     **/
    addGateway(AddGatewayRequestObject: AddBilldeskGatewayRequest | AddRazorpayGatewayRequest): Promise<RazorpayGatewayDetailsResponse | BilldeskGatewayDetailsResponse>;
    /**
     * Add AMC
     * @param data AddPgAmcRequest
     * @returns ListResponse<PgAmcBeneficiaryBankDetailsResponse>
     **/
    addAmc(data: AddPgAmcRequest): Promise<ListResponse<PgAmcBeneficiaryBankDetailsResponse>>;
    /**
     * Fetch AMC list with bank details
     * @returns ListResponse<PgAmcBeneficiaryBankDetailsResponse>
     **/
    fetchAmcBankDetails(): Promise<ListResponse<PgAmcBeneficiaryBankDetailsResponse>>;
    /**
     * Enable or Disable upi autopay
     * @returns UPIAutopayResponseObject
     **/
    configureUPIAutopay(data: UPIAutopayRequestObject): Promise<UPIAutopayResponseObject>;
}

declare const phoneNumberUrl = "/v2/phone_numbers";
interface PhoneNumberObject {
    object: string;
    id: string;
    profile: string;
    isd: string;
    number: string;
    belongs_to: string | null;
    created_at: string;
}
interface PhoneNumberCreateRequest {
    profile: string;
    isd: string;
    number: string;
    belongs_to?: string;
}
interface PhoneNumberUpdateRequest {
    id: string;
    belongs_to: string;
}
interface PhoneNumberFetchAllRequest {
    profile: string;
}

declare const phone_number_types_d_phoneNumberUrl: typeof phoneNumberUrl;
type phone_number_types_d_PhoneNumberObject = PhoneNumberObject;
type phone_number_types_d_PhoneNumberCreateRequest = PhoneNumberCreateRequest;
type phone_number_types_d_PhoneNumberUpdateRequest = PhoneNumberUpdateRequest;
type phone_number_types_d_PhoneNumberFetchAllRequest = PhoneNumberFetchAllRequest;
declare namespace phone_number_types_d {
  export {
    phone_number_types_d_phoneNumberUrl as phoneNumberUrl,
    phone_number_types_d_PhoneNumberObject as PhoneNumberObject,
    phone_number_types_d_PhoneNumberCreateRequest as PhoneNumberCreateRequest,
    phone_number_types_d_PhoneNumberUpdateRequest as PhoneNumberUpdateRequest,
    phone_number_types_d_PhoneNumberFetchAllRequest as PhoneNumberFetchAllRequest,
  };
}

declare class PhoneNumberService {
    private api;
    constructor(api: Api);
    /**
     * Fetch an PhoneNumber
     * @param id string
     * @returns PhoneNumberObject
     **/
    fetch(id: string): Promise<PhoneNumberObject>;
    /**
     * Create an PhoneNumber
     * @param data PhoneNumberCreateRequest object
     * @returns PhoneNumberObject
     **/
    create(data: PhoneNumberCreateRequest): Promise<PhoneNumberObject>;
    /**
     * Update the PhoneNumber
     * @param data PhoneNumberUpdateRequest
     * @returns PhoneNumberObject
     */
    update(data: PhoneNumberUpdateRequest): Promise<PhoneNumberObject>;
    /**
     * Fetch all PhoneNumbers
     * @returns PhoneNumberObjects list
     **/
    fetchAll(params: PhoneNumberFetchAllRequest): Promise<ListResponse<PhoneNumberObject>>;
}

declare const relatedPartyUrl = "/v2/related_parties";
interface RelatedPartyObject {
    object: string;
    id: string;
    profile: string;
    name: string;
    pan: string | null;
    date_of_birth: string | null;
    relationship: string;
    guardian_name: string | null;
    guardian_pan: string | null;
    created_at: string;
}
interface RelatedPartyCreateRequest {
    profile: string;
    name: string;
    pan?: string;
    date_of_birth?: string;
    relationship: string;
    guardian_name?: string;
    guardian_pan?: string;
}
interface RelatedPartyUpdateRequest {
    id: string;
    pan?: string;
    date_of_birth?: string;
    guardian_name?: string;
    guardian_pan?: string;
}
interface RelatedPartyFetchAllRequest {
    profile: string;
}

declare const related_party_types_d_relatedPartyUrl: typeof relatedPartyUrl;
type related_party_types_d_RelatedPartyObject = RelatedPartyObject;
type related_party_types_d_RelatedPartyCreateRequest = RelatedPartyCreateRequest;
type related_party_types_d_RelatedPartyUpdateRequest = RelatedPartyUpdateRequest;
type related_party_types_d_RelatedPartyFetchAllRequest = RelatedPartyFetchAllRequest;
declare namespace related_party_types_d {
  export {
    related_party_types_d_relatedPartyUrl as relatedPartyUrl,
    related_party_types_d_RelatedPartyObject as RelatedPartyObject,
    related_party_types_d_RelatedPartyCreateRequest as RelatedPartyCreateRequest,
    related_party_types_d_RelatedPartyUpdateRequest as RelatedPartyUpdateRequest,
    related_party_types_d_RelatedPartyFetchAllRequest as RelatedPartyFetchAllRequest,
  };
}

declare class RelatedPartyService {
    private api;
    constructor(api: Api);
    /**
     * Fetch an RelatedParty
     * @param id string
     * @returns RelatedPartyObject
     **/
    fetch(id: string): Promise<RelatedPartyObject>;
    /**
     * Create an RelatedParty
     * @param data RelatedPartyCreateRequest object
     * @returns RelatedPartyObject
     **/
    create(data: RelatedPartyCreateRequest): Promise<RelatedPartyObject>;
    /**
     * Update the RelatedParty
     * @param data RelatedPartyUpdateRequest
     * @returns RelatedPartyObject
     */
    update(data: RelatedPartyUpdateRequest): Promise<RelatedPartyObject>;
    /**
     * Fetch all RelatedParties
     * @returns RelatedPartyObjects list
     **/
    fetchAll(params: RelatedPartyFetchAllRequest): Promise<ListResponse<RelatedPartyObject>>;
}

declare const RTA_FAILURE_CODE_FP_DASHBOARD_URL = "/api/oms/operation/failure_code_mappings";
interface AddRTAFailureCodeRequestObject {
    gateway: string;
    rta_id: number;
    type: string;
    key: string;
    value: string;
}
interface AddRTAFailureCodeResponseObject {
    id: number;
    gateway: string;
    rta_id: number;
    type: string;
    key: string;
    value: string;
    created_at: string;
    updated_at: string;
}
interface RTAFailureCodeListObject {
    id: number;
    gateway: string;
    rta_id: number;
    type: string;
    key: string;
    value: string;
    created_at: string;
    updated_at: string;
    entity_version: string;
}
interface RTAFailureCodeListFilters {
    field: string;
    value: string;
    operator?: string;
}
interface RTAFailureCodeListPagination {
    page: number;
    limit: number;
}
interface RTAFailureCodeListSorting {
    column: string;
    order: string;
}
interface FailureCodesResponseObject {
    id: number;
    gateway: string;
    rta_id: number;
    type: string;
    key: string;
    value: string;
    created_at: string;
    updated_at: string;
}

declare const rta_failure_codes_types_d_RTA_FAILURE_CODE_FP_DASHBOARD_URL: typeof RTA_FAILURE_CODE_FP_DASHBOARD_URL;
type rta_failure_codes_types_d_AddRTAFailureCodeRequestObject = AddRTAFailureCodeRequestObject;
type rta_failure_codes_types_d_AddRTAFailureCodeResponseObject = AddRTAFailureCodeResponseObject;
type rta_failure_codes_types_d_RTAFailureCodeListObject = RTAFailureCodeListObject;
type rta_failure_codes_types_d_RTAFailureCodeListFilters = RTAFailureCodeListFilters;
type rta_failure_codes_types_d_RTAFailureCodeListPagination = RTAFailureCodeListPagination;
type rta_failure_codes_types_d_RTAFailureCodeListSorting = RTAFailureCodeListSorting;
type rta_failure_codes_types_d_FailureCodesResponseObject = FailureCodesResponseObject;
declare namespace rta_failure_codes_types_d {
  export {
    rta_failure_codes_types_d_RTA_FAILURE_CODE_FP_DASHBOARD_URL as RTA_FAILURE_CODE_FP_DASHBOARD_URL,
    rta_failure_codes_types_d_AddRTAFailureCodeRequestObject as AddRTAFailureCodeRequestObject,
    rta_failure_codes_types_d_AddRTAFailureCodeResponseObject as AddRTAFailureCodeResponseObject,
    rta_failure_codes_types_d_RTAFailureCodeListObject as RTAFailureCodeListObject,
    rta_failure_codes_types_d_RTAFailureCodeListFilters as RTAFailureCodeListFilters,
    rta_failure_codes_types_d_RTAFailureCodeListPagination as RTAFailureCodeListPagination,
    rta_failure_codes_types_d_RTAFailureCodeListSorting as RTAFailureCodeListSorting,
    rta_failure_codes_types_d_FailureCodesResponseObject as FailureCodesResponseObject,
  };
}

declare class RTAFailureCodeService {
    private api;
    constructor(api: Api);
    /**
     * Add a RTA failure code
     * @param data RTA failure codes request object
     * @returns RTA failure code response object
     **/
    add(data: AddRTAFailureCodeRequestObject): Promise<AddRTAFailureCodeResponseObject>;
    /**
     * Fetch all failure codes
     * @returns FailureCodesResponseObject list
     **/
    fetchAll(): Promise<ListResponse<FailureCodesResponseObject>>;
}

declare const RZP_TRANSFER_FP_DASHBOARD_URL = "/api/pg/transfers";
interface Transfer {
    object: string;
    status: string;
    payment_id: number;
    order_ids: string[];
    payment_reference: string;
    beneficiary_id: string;
    amount: number;
    transfer_reference: string;
    created_at: string;
    processed_at: string;
    failure_reason: string;
}
interface TransferResponse {
    object: string;
    data: Transfer[];
}

declare const rzp_transfers_types_d_RZP_TRANSFER_FP_DASHBOARD_URL: typeof RZP_TRANSFER_FP_DASHBOARD_URL;
type rzp_transfers_types_d_TransferResponse = TransferResponse;
declare namespace rzp_transfers_types_d {
  export {
    rzp_transfers_types_d_RZP_TRANSFER_FP_DASHBOARD_URL as RZP_TRANSFER_FP_DASHBOARD_URL,
    rzp_transfers_types_d_TransferResponse as TransferResponse,
  };
}

declare class RZPTransferService {
    private api;
    constructor(api: Api);
    /**
     * Get Razerpay Payment Transfers
     * @returns Razerpay Payment Transfers Object
     **/
    fetch(payment_id: string): Promise<TransferResponse>;
}

declare const SCHEDULED_QUERIES_BASE_URL = "/v2/reports";
interface ScheduledQuery {
    object: "list";
    id: string;
    title: string;
    sql: string;
    enabled: boolean;
    cron_schedule: string;
    start_date: string;
    created_at: string;
}
interface ScheduledQueryListResponse {
    object: "scheduled_query";
    data: ScheduledQuery[];
}
interface ScheduledQueryRun {
    object: string;
    id: string;
    scheduled_query: string;
    file: string | null;
    state: string;
    reason: string | null;
    created_at: string;
}
interface ScheduledQueryRunsListResponse {
    object: string;
    data: ScheduledQueryRun[];
}

declare const scheduled_queries_types_d_SCHEDULED_QUERIES_BASE_URL: typeof SCHEDULED_QUERIES_BASE_URL;
type scheduled_queries_types_d_ScheduledQuery = ScheduledQuery;
type scheduled_queries_types_d_ScheduledQueryListResponse = ScheduledQueryListResponse;
type scheduled_queries_types_d_ScheduledQueryRun = ScheduledQueryRun;
type scheduled_queries_types_d_ScheduledQueryRunsListResponse = ScheduledQueryRunsListResponse;
declare namespace scheduled_queries_types_d {
  export {
    scheduled_queries_types_d_SCHEDULED_QUERIES_BASE_URL as SCHEDULED_QUERIES_BASE_URL,
    scheduled_queries_types_d_ScheduledQuery as ScheduledQuery,
    scheduled_queries_types_d_ScheduledQueryListResponse as ScheduledQueryListResponse,
    scheduled_queries_types_d_ScheduledQueryRun as ScheduledQueryRun,
    scheduled_queries_types_d_ScheduledQueryRunsListResponse as ScheduledQueryRunsListResponse,
  };
}

declare class ScheduledQueriesService {
    private api;
    constructor(api: Api);
    /**
     * Fetch all Scheduled queries
     * @returns ScheduledQueryListResponse
     **/
    fetchScheduledQueries(): Promise<ScheduledQueryListResponse>;
    /**
     * Fetch an uploaded Folio feed
     * @param scheduled_query_id ID of a Scheduled query
     * @returns ScheduledQueryRunsListResponse
     **/
    fetchScheduledQueryRuns(scheduled_query_id: string): Promise<ScheduledQueryRunsListResponse>;
}

declare type planType = "mf_purchase_plans" | "mf_redemption_plans" | "mf_switch_plans";
interface SkipInstructionObject {
    object: string;
    id: string;
    plan: string;
    state: string;
    from_date: string;
    to_date: string | null;
    remaining_installments: string;
    skipped_installments: string;
    created_at: string;
    cancelled_at: string | null;
    completed_at: string | null;
}
interface SkipInstructionCreateRequest {
    from: string;
    to?: string;
}
interface SkipInstructionfetchAllParams {
    statuses?: string;
}

type skip_instruction_types_d_planType = planType;
type skip_instruction_types_d_SkipInstructionObject = SkipInstructionObject;
type skip_instruction_types_d_SkipInstructionCreateRequest = SkipInstructionCreateRequest;
type skip_instruction_types_d_SkipInstructionfetchAllParams = SkipInstructionfetchAllParams;
declare namespace skip_instruction_types_d {
  export {
    skip_instruction_types_d_planType as planType,
    skip_instruction_types_d_SkipInstructionObject as SkipInstructionObject,
    skip_instruction_types_d_SkipInstructionCreateRequest as SkipInstructionCreateRequest,
    skip_instruction_types_d_SkipInstructionfetchAllParams as SkipInstructionfetchAllParams,
  };
}

declare class SkipInstructionService {
    private api;
    constructor(api: Api);
    /**
     * Create a SkipInstruction
     * @param planType mf plan type
     * @param planId mf plan Id
     * @param data SkipInstructionCreateRequest object
     * @returns SkipInstructionObject
     **/
    create(planType: planType, planId: string, data: SkipInstructionCreateRequest): Promise<SkipInstructionObject>;
    /**
     * Fetch a SkipInstruction by id
     * @param planType mf plan type
     * @param skipInstructionId string
     * @returns SkipInstructionObject
     **/
    fetch(planType: planType, skipInstructionId: string): Promise<SkipInstructionObject>;
    /**
     * Cancel a SkipInstruction
     * @param planType mf plan type
     * @param skipInstructionId string
     * @returns SkipInstructionObject
     */
    cancel(planType: planType, skipInstructionId: string): Promise<SkipInstructionObject>;
    /**
     * Fetch all SkipInstructions
     * @param planType mf plan type
     * @param planId mf plan Id
     * @param params SkipInstructionfetchAllParams object
     * @returns SkipInstructionObject list
     **/
    fetchAll(planType: planType, planId: string, params?: SkipInstructionfetchAllParams): Promise<ListResponse<SkipInstructionObject>>;
}

declare const transactionUrl = "/transactions";
interface Sources {
    days_held: number;
    units: number;
    purchased_on: string;
    purchased_at: number;
    gain: number;
}
interface TransactionFetchAllRequest {
    folios: string;
    types?: string;
    from?: string | null;
    to?: string | null;
}
interface TransactionObject {
    object: string;
    folio_number: string;
    isin: string;
    type: string;
    amount: number;
    units: number | null;
    traded_on: string;
    traded_at: number;
    order: string | null;
    corporate_action: number | null;
    related_transaction_id: number | null;
    rta_order_reference: number | null;
    rta_product_code: number | null;
    rta_investment_option: number | null;
    rta_scheme_name: number | null;
    sources: Sources[];
}

declare const transaction_types_d_transactionUrl: typeof transactionUrl;
type transaction_types_d_TransactionFetchAllRequest = TransactionFetchAllRequest;
type transaction_types_d_TransactionObject = TransactionObject;
declare namespace transaction_types_d {
  export {
    transaction_types_d_transactionUrl as transactionUrl,
    transaction_types_d_TransactionFetchAllRequest as TransactionFetchAllRequest,
    transaction_types_d_TransactionObject as TransactionObject,
  };
}

declare class TransactionService {
    private api;
    constructor(api: Api);
    /**
     * This API used to fetch all transactions with a limit of 100.
     * @returns TransactionObjects list
     */
    fetchAll(params: TransactionFetchAllRequest): Promise<ListResponse<TransactionObject>>;
}

declare const userUrl = "/v2/auth";
interface CreateUserRequest {
    enabled: boolean;
    username: string;
    firstname?: string;
    lastname?: string;
    email?: string;
    attributes: {
        fp_identifier?: string;
        fp_user_type: string;
        mobile_number: string;
        [key: string]: string | undefined;
    };
}
interface CreateUserResponse {
    enabled: string;
    username: string;
    firstname?: string;
    lastname?: string;
    email?: string;
    attributes: {
        fp_identifier?: string;
        fp_user_type: string;
        mobile_number: string;
        [key: string]: string | undefined;
    };
}
interface FetchUserResponse {
    id: string;
    username: string;
    emailVerified: string;
    attributes: {
        [key: string]: [string];
    };
}
interface UpdateUserRequest {
    enabled: boolean;
    username: string;
    firstname?: string;
    lastname?: string;
    email?: string;
    attributes: {
        fp_identifier?: string;
        fp_user_type: string;
        mobile_number: string;
        [key: string]: string | undefined;
    };
}
interface UpdateUserResponse {
    enabled: string;
    username: string;
    firstname?: string;
    lastname?: string;
    email?: string;
    attributes: {
        [key: string]: string;
    };
}
interface SearchUserRequest {
    username: string;
}
interface SearchUserResponse {
    id: string;
    username: string;
    emailVerified: string;
    attributes: {
        [key: string]: [string];
    };
}

declare const user_types_d_userUrl: typeof userUrl;
type user_types_d_CreateUserRequest = CreateUserRequest;
type user_types_d_CreateUserResponse = CreateUserResponse;
type user_types_d_FetchUserResponse = FetchUserResponse;
type user_types_d_UpdateUserRequest = UpdateUserRequest;
type user_types_d_UpdateUserResponse = UpdateUserResponse;
type user_types_d_SearchUserRequest = SearchUserRequest;
type user_types_d_SearchUserResponse = SearchUserResponse;
declare namespace user_types_d {
  export {
    user_types_d_userUrl as userUrl,
    user_types_d_CreateUserRequest as CreateUserRequest,
    user_types_d_CreateUserResponse as CreateUserResponse,
    user_types_d_FetchUserResponse as FetchUserResponse,
    user_types_d_UpdateUserRequest as UpdateUserRequest,
    user_types_d_UpdateUserResponse as UpdateUserResponse,
    user_types_d_SearchUserRequest as SearchUserRequest,
    user_types_d_SearchUserResponse as SearchUserResponse,
  };
}

declare class UserService {
    private api;
    constructor(api: Api);
    /**
     * Create User
     * @param data UserCreateRequest object
     * @returns UserCreateResponse
     */
    createUser(data: CreateUserRequest, tenant?: string): Promise<CreateUserResponse>;
    /**
     * Fetch User (Self)
     * @returns FetchUserResponse
     */
    fetchUser(tenant?: string): Promise<FetchUserResponse>;
    /**
     * Update User
     * @param data UpdateUserRequest object
     * @returns UpdateUserResponse
     */
    updateUser(data: UpdateUserRequest, tenant?: string): Promise<UpdateUserResponse>;
    /**
     * Search User
     * @param data SearchUserRequest object
     * @returns SearchUserResponse
     */
    searchUser(data: SearchUserRequest, tenant?: string): Promise<SearchUserResponse>;
}

interface UserAuthConfig {
    authUrl: string;
    client_id: string;
    redirect_uri: string;
    post_logout_redirect_uri: string;
}
interface InvestorTokenResponse {
    access_token: string;
    expires_in: number;
    id_token: string;
    ["not-before-policy"]: number;
    refresh_expires_in: number;
    refresh_token: string;
    scope: string;
    session_state: string;
    token_type: string;
}
interface UserProfile {
    fp_identifier: string;
    preferred_username: string;
    session_state: string;
    sid: string;
    sub: string;
    tenant: string;
    typ: string;
    type: string;
}
interface AuthenticatedUser {
    access_token: string;
    expires_in: number;
    id_token: string;
    ["not-before-policy"]: number;
    refresh_expires_in: number;
    refresh_token: string;
    scope: string;
    session_state: string;
    token_type: string;
    profile: UserProfile;
}
interface OtpVerificationRequest {
    session_code: string;
    client_id: string;
    execution: string;
    auth_session_id: string;
    tab_id: string;
}
interface InitiateSignInResponse {
    session_code: string;
    client_id: string;
    execution: string;
    auth_session_id: string;
    tab_id: string;
    challenge: string;
}
interface OtpResponse {
    state: string;
    session_state: string;
    code: string;
}
interface AuthorizationCodeResponse {
    access_token: string;
    expires_in: number;
    id_token: string;
    ["not-before-policy"]: number;
    refresh_expires_in: number;
    refresh_token: string;
    scope: string;
    session_state: string;
    token_type: string;
    profile: UserProfile;
    state: string;
}
interface InitiateSignInRequest {
    response_type: string;
    scope: string;
    code_challenge_method: string;
    response_mode: string;
    login_hint: string;
    state: string;
    redirect_uri: string;
    client_id: string;
    code_challenge: string;
}
interface LogoutResponse {
    state: string;
    userState: string;
}

type user_auth_types_d_UserAuthConfig = UserAuthConfig;
type user_auth_types_d_InvestorTokenResponse = InvestorTokenResponse;
type user_auth_types_d_UserProfile = UserProfile;
type user_auth_types_d_AuthenticatedUser = AuthenticatedUser;
type user_auth_types_d_OtpVerificationRequest = OtpVerificationRequest;
type user_auth_types_d_InitiateSignInResponse = InitiateSignInResponse;
type user_auth_types_d_OtpResponse = OtpResponse;
type user_auth_types_d_AuthorizationCodeResponse = AuthorizationCodeResponse;
type user_auth_types_d_InitiateSignInRequest = InitiateSignInRequest;
type user_auth_types_d_LogoutResponse = LogoutResponse;
declare namespace user_auth_types_d {
  export {
    user_auth_types_d_UserAuthConfig as UserAuthConfig,
    user_auth_types_d_InvestorTokenResponse as InvestorTokenResponse,
    user_auth_types_d_UserProfile as UserProfile,
    user_auth_types_d_AuthenticatedUser as AuthenticatedUser,
    user_auth_types_d_OtpVerificationRequest as OtpVerificationRequest,
    user_auth_types_d_InitiateSignInResponse as InitiateSignInResponse,
    user_auth_types_d_OtpResponse as OtpResponse,
    user_auth_types_d_AuthorizationCodeResponse as AuthorizationCodeResponse,
    user_auth_types_d_InitiateSignInRequest as InitiateSignInRequest,
    user_auth_types_d_LogoutResponse as LogoutResponse,
  };
}

declare class OtpChallenge {
    private api;
    private userAuthConfig;
    constructor(api: Api, userAuthConfig: UserAuthConfig);
    verify(params: OtpVerificationRequest, otp: string): Promise<OtpResponse | InitiateSignInResponse>;
}

declare class UserAuthService {
    private api;
    private userAuthConfig;
    constructor(api: Api, userAuthConfig: UserAuthConfig);
    /**
     * Get user from session
     * @return {object} The user object
     */
    getAuthenticatedUser(): Promise<AuthenticatedUser | null>;
    /**
     * Initiates login by getting the type of challenge
     * @param {string} investor_id - Investor ID
     * @param {string} context - Path to be redirected after login completes
     */
    initiateSignIn(login_hint: string, context: string): Promise<InitiateSignInResponse>;
    /**
     * Call API with authorization code and code verifier to get access token
     * @param {string} code - Authorization code received in the previous step of protocol
     */
    verifyAuthorizationCode(code: string): Promise<AuthorizationCodeResponse>;
    /**
     * Call API to get a new access token
     */
    refreshToken(): Promise<void>;
    /**
     * Initiate logout by calling API
     * @param {string} context - Path to be redirected after logout completes
     */
    initiateLogout(context: string): Promise<LogoutResponse>;
    /**
     * Factory method for returning challenge instance
     * @param {string} challenge - Challenge which needs to be initialized
     */
    getChallenge(challenge: string): OtpChallenge;
}

interface InitParamsObject {
    token?: string;
    hostUrl: string;
    headers?: {
        [key: string]: string;
    };
}
interface FpI {
    addresses(): AddressService;
    api_logs(): ApiLogsService;
    authentication(): AuthService;
    bank_accounts(): BankAccountService;
    demat_accounts(): DematAccountsService;
    email_addresses(): EmailAddressService;
    esigns(): EsignService;
    events(): EventsService;
    files(): FileService;
    file_operations(): FileOperationService;
    investor_profiles(): InvestorProfileService;
    investor_reports(): InvestorReportService;
    investors(): InvestorService;
    kyc_checks(): KycCheckService;
    kyc_requests(): KycRequestService;
    mandates(): MandateService;
    master_data(): MasterDataService;
    mf_folios(): MfFolioService;
    mf_investment_accounts(): MfInvestmentAccountService;
    mf_purchases(): MfPurchaseService;
    mf_purchase_plans(): MfPurchasePlanService;
    mf_redemptions(): MfRedemptionService;
    mf_redemption_plans(): MfRedemptionPlanService;
    mf_settlement_details(): MfSettlementDetailService;
    mf_switches(): MfSwitchService;
    mf_switch_plans(): MfSwitchPlanService;
    other_reports(): OtherReportService;
    partners(): PartnerService;
    payments(): PaymentService;
    payments_gateways(): PaymentsGatewayService;
    phone_numbers(): PhoneNumberService;
    related_parties(): RelatedPartyService;
    rta_failure_codes(): RTAFailureCodeService;
    rzp_payment_transfers(): RZPTransferService;
    scheduled_queries(): ScheduledQueriesService;
    skip_instructions(): SkipInstructionService;
    transactions(): TransactionService;
    users(): UserService;
}

declare class Fp implements FpI {
    private api;
    constructor(options: InitParamsObject);
    addresses(): AddressService;
    api_logs(): ApiLogsService;
    authentication(): AuthService;
    bank_accounts(): BankAccountService;
    demat_accounts(): DematAccountsService;
    email_addresses(): EmailAddressService;
    esigns(): EsignService;
    events(): EventsService;
    files(): FileService;
    file_operations(): FileOperationService;
    investor_profiles(): InvestorProfileService;
    investor_reports(): InvestorReportService;
    investors(): InvestorService;
    kyc_checks(): KycCheckService;
    kyc_requests(): KycRequestService;
    mandates(): MandateService;
    master_data(): MasterDataService;
    mf_folios(): MfFolioService;
    mf_investment_accounts(): MfInvestmentAccountService;
    mf_purchases(): MfPurchaseService;
    mf_purchase_plans(): MfPurchasePlanService;
    mf_redemptions(): MfRedemptionService;
    mf_redemption_plans(): MfRedemptionPlanService;
    mf_settlement_details(): MfSettlementDetailService;
    mf_switches(): MfSwitchService;
    mf_switch_plans(): MfSwitchPlanService;
    other_reports(): OtherReportService;
    partners(): PartnerService;
    payments(): PaymentService;
    payments_gateways(): PaymentsGatewayService;
    phone_numbers(): PhoneNumberService;
    related_parties(): RelatedPartyService;
    rta_failure_codes(): RTAFailureCodeService;
    rzp_payment_transfers(): RZPTransferService;
    scheduled_queries(): ScheduledQueriesService;
    skip_instructions(): SkipInstructionService;
    transactions(): TransactionService;
    users(): UserService;
    userAuthentication(userAuthConfig: UserAuthConfig): UserAuthService;
}
declare const fp: typeof Fp;

/**
 * Validate phone number. Only isd with value `91` is supportd. ex.9998765432
 *
 * @param str phone number to be validated
 * @param isd Isd code for the phone number
 * @returns {@code boolean} based on the test
 */
declare function phoneNumber(str: string, isd?: string): boolean;
/**
 * Validate IFSC. Ex. IFSC0112233
 *
 * @param str Ifsc to be validated
 * @returns {@code boolean} based on the test
 */
declare function ifsc(str: string): boolean;
/**
 * Validate 12 digit aadhar number. ex. 3456 78911 2345
 *
 * @param str Aadhar number to be validated with spaces after every 4th character.
 * @returns {@code boolean} based on the test
 */
declare function aadhar(str: string): boolean;
/**
 * Validate bank account number.
 *
 * @param str Bank Account number to be validated
 * @returns {@code boolean} based on the test
 */
declare function bankAccountNumber(str: string): boolean;

declare const validators_d_phoneNumber: typeof phoneNumber;
declare const validators_d_ifsc: typeof ifsc;
declare const validators_d_aadhar: typeof aadhar;
declare const validators_d_bankAccountNumber: typeof bankAccountNumber;
declare namespace validators_d {
  export {
    validators_d_phoneNumber as phoneNumber,
    validators_d_ifsc as ifsc,
    validators_d_aadhar as aadhar,
    validators_d_bankAccountNumber as bankAccountNumber,
  };
}

export { AddBilldeskGatewayRequest, AddPgAmcRequest, AddRTAFailureCodeRequestObject, AddRTAFailureCodeResponseObject, AddRazorpayGatewayRequest, address_types_d as Address, AddressCreateRequest, AddressFetchAllRequest, AddressObject, AddressUpdateRequest, Amc, AmcResponse, ApiLogParams, ApiLogResponseObject, api_logs_types_d as ApiLogs, auth_types_d as Auth, AuthenticatedUser, AuthorizationCodeResponse, BSEGatewayDetailsResponse, bank_account_types_d as BankAccount, BankAccountCreateRequest, BankAccountFetchAllRequest, BankAccountObject, BankAccountUpdateRequest, BilldeskGatewayDetailsResponse, Country, CountryResponse, CreateUserRequest, CreateUserResponse, DematAccountObject, demat_accounts_types_d as DematAccounts, DematAccountsCreateRequest, DematAccountsFetchAllRequestParams, email_address_types_d as EmailAddress, EmailAddressCreateRequest, EmailAddressFetchAllRequest, EmailAddressObject, EmailAddressUpdateRequest, esign_types_d as Esign, EsignCreateRequest, EsignObject, EventData, EventObject, events_types_d as Events, EventsFetchAllRequestParams, FailureCodesResponseObject, FetchUserResponse, file_types_d as File, file_operation_types_d as FileOperation, FileOperationCreateRequest, FileOperationObject, FileOperationsFetchAllRequestParams, FileOperationsFetchAllResponse, FileResponse, FilterByRequest, FolioDefaults, Fp, FpI, FrequencySpecificObject, FundSchemesParams, GetGatewayDetailsRequestObject, GetPaymentsGetwayResponse, GetTokenResponse, IGatewayUpdateRequestObject, IfscCodeResponse, InitiateSignInRequest, InitiateSignInResponse, InvestorAddress, InvestorBankAccount, InvestorContactDetails, InvestorCreateRequest, InvestorFatcaDetails, InvestorFetchAllRequestParams, InvestorKycIdentityDetails, InvestorListAllResponse, InvestorListReportRequest, InvestorNomination, InvestorNominee, InvestorObject, investor_profile_types_d as InvestorProfile, InvestorProfileCreateRequest, InvestorProfileFetchAllRequest, InvestorProfileObject, InvestorProfileUpdateRequest, investor_report_types_d as InvestorReport, InvestorReportCapitalGainFetchRequest, InvestorReportCapitalGainFetchResponse, InvestorReportHoldingsFetchAllRequest, InvestorReportHoldingsFetchRequest, InvestorReportHoldingsFetchResponse, InvestorReportInvestmentAccountWiseReturnsFetchRequest, InvestorReportInvestmentAccountWiseReturnsFetchResponse, InvestorReportSchemewiseReturnsFetchRequest, InvestorReportSchemewiseReturnsResponse, InvestorSearchRequestParams, InvestorTokenResponse, InvestorUpdateRequest, investors_types_d as Investors, kyc_check_types_d as KycCheck, KycCheckCreateRequest, KycCheckResponse, kyc_request_types_d as KycRequest, KycRequestCreateRequest, KycRequestFetchAllRequest, KycRequestPatchRequest, KycRequestResponse, KycRequestSimulateRequest, LogoutResponse, mandate_types_d as Mandate, MandateAuthorizeRequest, MandateAuthorizeResponse, MandateCreateRequest, MandateCreateResponse, MandateFetchAllRequest, MandateFetchAllResponse, MandateFetchResponse, master_data_types_d as MasterData, mf_folio_types_d as MfFolio, MfFolioFetchAllRequest, MfFolioObject, mf_investment_account_types_d as MfInvestmentAccount, MfInvestmentAccountCreateRequest, MfInvestmentAccountFetchAllRequest, MfInvestmentAccountObject, MfInvestmentAccountUpdateRequest, mf_purchase_types_d as MfPurchase, MfPurchaseCreateRequest, MfPurchaseFetchAllRequest, MfPurchaseObject, MfPurchasePatchRequest, mf_purchase_plan_types_d as MfPurchasePlan, MfPurchasePlanCreateRequest, MfPurchasePlanFetchAllRequest, MfPurchasePlanObject, MfPurchasePlanUpdateRequest, mf_redemption_types_d as MfRedemption, MfRedemptionCreateRequest, MfRedemptionFetchAllRequest, MfRedemptionObject, mf_redemption_plan_types_d as MfRedemptionPlan, MfRedemptionPlanCreateRequest, MfRedemptionPlanFetchAllRequest, MfRedemptionPlanObject, MfRedemptionPlanUpdateRequest, MfRedemptionUpdateRequest, mf_settlement_detail_types_d as MfSettlementDetail, MfSettlementDetailCreateRequest, MfSettlementDetailFetchAllRequest, MfSettlementDetailObject, MfSettlementDetailPatchRequest, mf_switch_types_d as MfSwitch, MfSwitchCreateRequest, MfSwitchFetchAllRequest, MfSwitchObject, MfSwitchPatchRequest, mf_switch_plan_types_d as MfSwitchPlan, MfSwitchPlanCreateRequest, MfSwitchPlanFetchAllRequest, MfSwitchPlanObject, MfSwitchPlanUpdateRequest, OAuthTokenOptions, other_report_types_d as OtherReport, OtpResponse, OtpVerificationRequest, partner_types_d as Partner, PartnerCreateRequest, PartnerObject, PartnerSearchRequest, payment_types_d as Payment, PaymentCreateNachRequest, PaymentCreateNachResponse, PaymentCreateRequest, PaymentCreateResponse, PaymentFetchAllRequest, PaymentFetchAllResponse, PaymentObject, payments_gateway_types_d as PaymentsGateway, PgAmcBeneficiaryBankDetailsResponse, PgTenantSetupObject, phone_number_types_d as PhoneNumber, PhoneNumberCreateRequest, PhoneNumberFetchAllRequest, PhoneNumberObject, PhoneNumberUpdateRequest, PincodeResponse, PostPaymentVerificationErrorResponse, PostPaymentVerificationRequest, PostPaymentVerificationResponse, PurchaseListReportRequest, RTAFailureCodeListFilters, RTAFailureCodeListObject, RTAFailureCodeListPagination, RTAFailureCodeListSorting, RazorpayGatewayDetailsResponse, RedemptionListReportRequest, related_party_types_d as RelatedParty, RelatedPartyCreateRequest, RelatedPartyFetchAllRequest, RelatedPartyObject, RelatedPartyUpdateRequest, ReportResponse, rta_failure_codes_types_d as RtaFailureCodes, rzp_transfers_types_d as RzpTransfers, scheduled_queries_types_d as ScheduledQueries, ScheduledQuery, ScheduledQueryListResponse, ScheduledQueryRun, ScheduledQueryRunsListResponse, SchemeResponse, SchemesListResponse, SearchUserRequest, SearchUserResponse, skip_instruction_types_d as SkipInstruction, SkipInstructionCreateRequest, SkipInstructionObject, SkipInstructionfetchAllParams, StateResponse, TokenObject, transaction_types_d as Transaction, TransactionFetchAllRequest, TransactionObject, TransferResponse, UPIAutopayRequestObject, UPIAutopayResponseObject, UpdateUserRequest, UpdateUserResponse, user_types_d as User, user_auth_types_d as UserAuth, UserAuthConfig, UserProfile, validators_d as ValidatorUtils, fp };
